/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_CHAFFVERB_HPP_
#define _HEAVY_CONTEXT_CHAFFVERB_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalPhasor.h"
#include "HvControlBinop.h"
#include "HvControlTabhead.h"
#include "HvSignalRPole.h"
#include "HvSignalVar.h"
#include "HvSignalTabread.h"
#include "HvControlCast.h"
#include "HvControlRandom.h"
#include "HvControlSystem.h"
#include "HvControlDelay.h"
#include "HvSignalDel1.h"
#include "HvSignalLine.h"
#include "HvTable.h"
#include "HvMath.h"
#include "HvSignalTabwrite.h"
#include "HvControlSlice.h"
#include "HvControlIf.h"
#include "HvControlVar.h"
#include "HvControlUnop.h"
#include "HvControlPack.h"

class Heavy_ChaffVerb : public HeavyContext {

 public:
  Heavy_ChaffVerb(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_ChaffVerb();

  const char *getName() override { return "ChaffVerb"; }
  int getNumInputChannels() override { return 1; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        A__LFO_PERIOD = 0x1F30993F, // A__LFO_Period
        A__LFO_STEPS_SCALE__TYPE2 = 0x1A2B8E9F, // A__LFO_Steps_Scale__Type2
        A__LFO_STEPS__TYPE2 = 0xBE3344C8, // A__LFO_Steps__Type2
        A__LFO_SWITCH = 0x7369936E, // A__LFO_Switch
        A__LFO_TYPE = 0xD64CFD23, // A__LFO_type
        B__GENERAL_OFFSET = 0x51447E19, // B__General_Offset
        B__GENERAL_SCALE = 0xA10FCFC4, // B__General_Scale
        C__RANDOM_LFO_OFFSET = 0x7EFB8E46, // C__Random_LFO_Offset
        C__RANDOM_LFO_PERIOD = 0xE6223016, // C__Random_LFO_Period
        C__RANDOM_LFO_SCALE = 0x3281900D, // C__Random_LFO_Scale
        C__RANDOM_LFO_SWITCH = 0x6150BC53, // C__Random_LFO_Switch
        D__SHIFT_MICROTONE = 0x9CBB1BF3, // D__Shift_Microtone
        D__SHIFT_TRANSPOSE = 0x4439D71, // D__Shift_Transpose
        E__FX_LEVEL = 0x890283C2, // E__Fx_Level
        E__HIPASS_FREQ = 0x12962685, // E__HiPass_Freq
        E__SHIFT_DELAY = 0x183CFEE5, // E__Shift_Delay
        E__SHIFT_WINDOW = 0x57FF40DB, // E__Shift_Window
        F__FX_DELAY = 0x69A91334, // F__FX_Delay
        F__FX_DELAY_FEEDBACK = 0x68D029F7, // F__FX_Delay_Feedback
        MIX__DRY_MIX = 0xD63693D0, // Mix__Dry_Mix
        MIX__DRY_VOL = 0x1FC3C02C, // Mix__Dry_Vol
        MIX__REVERB_LEVEL = 0x58653D84, // Mix__Reverb_Level
        MIX__REVERB_VOL = 0xE764F673, // Mix__Reverb_Vol
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_cluz104w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_AD9WCCnh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_OeLRRMte_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_KIegRoR1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rIIaJH8v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ahNjGUMr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_PEhMOqG0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_l0pAHdj0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YrggNKTg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xiyIUFDP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_dMKjpoG3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_I7sd1bMA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_SEfwrYrw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_88WNRSlm_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_qpo70477_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_8ADo5qiG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pPPXFtdL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HeYLFzCd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_152DjYlZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2UMtDSzr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RI1gwrcJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PlHESZDA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PabYxCZS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hrDWzKpe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1mD8oCk9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_i4dbjr9X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h3yqSZMw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mmRYOpQj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_spqPlCOv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jN9gxhTI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_50UXcZTL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_d88K8eWF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_gSIhklGo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VOnYMirm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fWC9TLtt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_16tiqgOF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZzqV0Wrk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z3q7wihp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8wsiVo4Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FtG5ge5K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hW9n9UyI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PjcqGZLb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VbWwaabz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kgEd5FjH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZOqCrqcW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Qu6BhrSo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kwJugb8M_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_m9HLIKZo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SkOFFj4l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JvHLgw2s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hE7ZfJhP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IWvwelh8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hA4fkERM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vUvCpcOa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fqfW3nUH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0jABJO2R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RlwBxr5n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LCO6Vpyv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5ouTwwmN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cwYgPxFR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gjz5q2LE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y9LpSix2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v1n9RbOe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mNc7OmaJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_6tz4Csag_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_yewPOf3t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cRandom_1VycPsHK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_j3y1it7M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hZZHMQyp_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_C3TAoQXZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5Nr6ftid_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FDF7kgcE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_NGGZuGIF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QuhCQpwm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iamErm6I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vCucB2G2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5PYXhRoO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Wdt8ql6g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_f5scY1oh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A7Ttnv2X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_tmlvm2ca_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZfGG7kUd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_7veAeliV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ppEuWDOd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_lbMhGGh8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j8ZJgMdB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UdFuZ2oT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X8y8pulQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FLFTLZvw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IVCTHa0K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_falKzTu4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7PoeOOYi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xMRBQ0F0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sHtleF7k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vq8Nevjs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YxkxWfZT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_77nigPNO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_2zXlWrsb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zjxJnl4v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_cZYcE095_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Sw6GbnAT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_DXoi3xNF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_QXGvgeGM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_rgWwA9DW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XM62KSBn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G0xilt08_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UVeXvTfP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_5HYef4S7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PSvwghLq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5b8FMd0o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CBqWEhec_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7c1eLwF9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_idT466zx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W7ZNk5qV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RKFY2Or3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Vdijw31d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_Rx211Gl0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xnYlNBKh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_p996eKX8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wnPFyn0B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xGdiGprP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_GPq6X1xj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_3Ak4ouDU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8JstMwXw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G6xYtOEN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CikmU2x1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_FJ9Gl3px_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CYakC6wp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S4U6S2wN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ds5ZulnE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0PYOrqZY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gVrtZDau_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SLKi51Hy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eE9xk2dd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tZJcC2eM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_xMW0s7PV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w5nA9XG4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ZiWKV6i9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JiFE195Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_v1UtFv5S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_jt08iaCM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_1pZDNPqC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IVWZgiW8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aXXh7TDd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CJbQoirA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Er6CD2m0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_67NK65Nh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QMYj1bI6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q3uOWQhs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NOVskrzd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QORjxBgk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QpfRXW03_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C9ZgeSuI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Fa21SR58_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Mv4xBO6o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_aYoS0I4Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_nQmcczef_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_CF6yMHOm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_UhTLInla_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_VNictWua_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_7P3o9gMy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PZE44VL1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SDq1LMjP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OaTZ5VwQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gxGQWsjm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sj6fAwRS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4LGpty51_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VkivXlYp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_qP30LYTJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_x5gKqtX9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_xXKLG6nr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_nB6o53dS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_DByGilSJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_gs61gmfv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L42fiWwo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SlNQPlFE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZLl7AdII_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Jb26kOPy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pyorebGn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WeQ4Lxwb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jSscqJZr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_AC5SrtDu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_1gsC74wu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_gqIkb1WM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OsGtzoR1_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_Jcgw7ocj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_ISG38vW3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3TbqKRq6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ag1QM7qI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wrNS3yvH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RsNoP64V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zgCKkVNu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_61oWFkDz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wyFh5gnp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_LXojPdK4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_N4lkxbed_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_KQecCqRY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5bhuNfYh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_ygwjhYho_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_tVWrUQip_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GM1EEFMB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QubCm8Ky_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X5qxt669_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ERTKu2ed_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IdOdK6nN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hsknai8B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_ysisArw1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_IMfhzYHs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7Bgzmzco_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n5EYSupL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2FIEZts5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3Kuvqjub_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_BqYBjMsa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UhTa0DbQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7MFrD751_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PaxlrcFD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a3uEsaFh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4Oy6z3b7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TjUt8cfW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Hnu0ImOb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZyF3XWg3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rZczA09m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_D0IlWBbM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_sZVILnq5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0oPYiTGS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eOKuyQRq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mCtb5K1s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Alf0coaY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_vIPjtkoa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_REx4CoTP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_NzN48K05_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_gYiktADP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_PvYwtS1q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_r2cmE7It_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oluHNGsk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M0pZcvnd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6WodPdwz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LWAeWTGK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4jsVpnoN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_83qGeIKB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_SUKWcMMa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_v1qa1HXn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fLhq5byw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_f0Fq9lAy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_BYxoKq50_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_z75OKMqg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_G1SDi5ZH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5vuMbhgD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oVHK2658_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MWqPR4Jp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ylIDBCy9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xQboDXII_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vxJhGkh6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e21ESNrm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qRrjtBu3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7fn3Uuk0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VyPkTbxz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c2h3kxVM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eHSki6UL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CnVCIINV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JBo36tML_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_SZH4f8vZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_15vycgP4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ysmKgXQS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_7EW0VPcG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_URpUJA48_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HdCUeHrF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E1BdOahe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UBGnNBmq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K1EPPJev_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dflkirOc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mU99j3Sw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_TDE7z6fi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rqU2zSqx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_bg0uxXNH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_u1eOx5yP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_MRjbLZZT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_M81ncLR1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_D6Yszqpj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VLODo76A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9IAgwH0w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pX8CSwhn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_NI79Vzc7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X9Yxjf5q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FJNm3kCy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OUcxLTHF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wCK7l7hX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tc47mZk5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O6A1elOr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l1G10hPH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_e7zMxX7Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Leyv0cfT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_l0jKFGf4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_M7cDhrrN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ZHFh339D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_rUPllykS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_8Zh7iMWx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_TkDvhtvi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wX7vDkU1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3pTvB4U4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w78KtTXu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uU8pkajZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ww6pC9dY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TvflXALl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_MnyGpRp5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AMa1zYcx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Iy5j61Lv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_a0vya4bC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_JhObY49w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_iBbI1zou_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_AKzQNmPk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lP2J3Xln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xfeu4pQ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DAguFkuB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_DWiBkQzu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_60FJoj5E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SPjS0shm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iLQpyHzm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8zxIf878_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CvPRc3Ho_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qOVVG4wy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pL8yMn1I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gCAy8555_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8ex0AYhD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_mFPYTkpK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Inzg5KFv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_VzKYvr8f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Pn1L4I5f_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_RgM3gUIb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_0ajfZMEY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dLq7WqFW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_faJcnOfn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Olp469QW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ojMx6C3x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VsJf8X86_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mCtDQNYV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_Ni9gslk7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XU3A0b54_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_SEa406mH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CIS60FzH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_CUvzfoGB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_igQF6fRj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_lRbL4hdp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QknBrir8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dlVXgQl7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zJeU2Lmk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_0xVqCYaZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fwH12Ljo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Kual2FRi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_97bDg6Jg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8cOKDLtW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gSt5gQA7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vu6lCv1u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yr7jGdyo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VA7RLFK9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zQBoeYIJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_QoxFiR1U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_qhv4rS7t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_5zfXzVyg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_cQ2VYcvS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_wjbB7M3A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_FrHixOBB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6cujA47n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p9JzKQ5M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aEOU1QhQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nzO8HXHF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pfNtXL2w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ls4zDvux_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_6kLrEwM8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PN2OqB6C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_zdns2dhv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hrAX5gyS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_4WRJV5qe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_qiGANPvY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_dU5YsroQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q1V4ts1Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E4wNv3dh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AsTRbLJH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_U7iMVUDZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kdKv8S5k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ri2MGkyo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oddK0mys_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_D0pkayHU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RdizJPX4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5q4fstTv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6ScYRVsm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MSMlS1ZE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uQtxBbMc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_UAeYv72F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Sl7JcsbL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_BdzT4Pzp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_B5tiwLw9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_sRaf3js8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_ZO1cJ2EM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_osZJzicY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H5JjMAEB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FoCU1CuS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X14qS9Wx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5jUj0xnp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_R3IMqFvx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_FBCmFB60_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q6TQsLI1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_KWAODDhB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_0QKLlUiN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_RAX58SO3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_IlowjLH7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_2MvsNWAi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zUHCVro6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PRvAPGQx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2QkhpdKV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_gcc0iHoS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kZCLbnen_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jrZ6nZrB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B365BTga_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nWWXZpXL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SJocBX9R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2SvDVIOO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c1tV8sSn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Fp5AMqbo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2KsF02Dp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_k39vTacD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_Mb24BZRo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_48osh9i0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gAe6dnJC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_QUs4hipB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gsUblF5C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F6cr4ED5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0fZN16vl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aBehNtXp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gUJGm7dg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ive3cAy3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_C6Wo7gO9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jU3Kljw4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Ae9JIlog_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Sy7SfvzH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TKeyVaqw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BUN9jMcA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_80jkNOiO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DZ9kwMSy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aQjsRobr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rKb5XsuP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Au55F8qH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_gJrN4V8L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cOBDJjLn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rqWce3PV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NglxyiL2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HiMV5gQl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CgSrjonQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nmp8Y2tz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QqMx5MH8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_k5sMsTmL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oNDn597y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_48NfRWTZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_yhedabSE_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_0FCbEKII_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W1fNGiKx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XXndXCk9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_1oNITt1a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RlrjzoPj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zdHOpDjt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OSqxxAiv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pJv9GBgR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G2BQxeqd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_eNNMsWrr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_K8GWTKZM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_JKSQOcaQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_R0iXejxy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_1rtvzaaV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lzVNPVG9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_btthTLxM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_5DQJrokY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Q0x28SwE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_565aod2N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_fq48Qo7C_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_khLZ1gxD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_LsKykipe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Jnxdw4F9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SHG5UcaM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9Ic8nEcV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LY7Lz6t1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y7BL1zgb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Fe2N1ebk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_2OmiD6Le_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LXwM5mQq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ddTe376J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_THWGNupx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_QDyiDah0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_PKH42TsK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_wW3KMCVs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gAr1GLCQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QDLXB31W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1us3fHGC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_iQGZ8Uye_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2x9ZRQs6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aBlnF8As_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TimPI1G3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4A9d8Djz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_McjZssj1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bGqrCd6D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LqkvS2rw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4HTpfWee_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_genib9NS_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_BOG7qWCw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zfMBZTj6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3VJynfpy_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_EBXHJNgw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8GXBPUWE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_va9MzQbx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_f5SbFhSj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KSukTfiC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bwQTItBM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_g79aMT23_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_YefWu4gU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3iprGRq9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dJrQvQdV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_U3AlKKG7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_hFoKbfml_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_CcHWseRU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_mNyH3nOO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wQQSqfX8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_XLwnfoJo_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_7CV6lEbb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_bCfXIFPf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Bfw6B9uT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4NUSv0eF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iq4qr1r2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8Unyo4u1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wlC0sROc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jpqmNaii_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PNHac9kw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_1l1qjTrq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hqOg6l6l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hYv6pzV2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_utX0ySsi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_igFfkiHj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o5l2Or9K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_drlxqODw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D9hyekGK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JOhzetGD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o4bIfA3m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WsLJXTAZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6HEXrp9a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bj1jNnXG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mh2vjejf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kEA2gxFH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qKiZN8Ky_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y9yHWULy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AExjEGgI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oMtVWgsB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hUa5yZYc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ssrgjj8z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tzY93vAF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NTfEdikI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n5UBUUiL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BAj5U73K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aDygP1yv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RGLCsVDo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gbw15IyB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UAujDSWU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ECDOjZOn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UuQhD1vs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vrOWX2JR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T3hVmpSb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nF6zMUT3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u8bTFIuH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_788QrljP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9MnAc84P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hQQuv3pF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hsnWwE3u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BYIKNKG3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2IwOxLo4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UuXSubnO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Qh6vFPw0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_S7XAatKi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_olJ9m7DJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CnRukJ3q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l1ie7CNs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FGk7uWmJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6Y8PONyG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_p4H9a42g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_G6NNgzXJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zVgv6CPY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uvlfLd9S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pzvHUdR0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mNxTGuNK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_k4Rs6aUA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_q40WJUvW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0ltOgt84_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_w4g9ny8C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PMmqFmxH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0yyTzYtm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JeZIaYS1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_e6amkfJu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_aHUlOjBN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_aSHpKxhm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QarmNs34_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_70mwynwG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_F2guKTqU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gTLuhfEZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cbDZKIdA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IHGoGECn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3PvcGdss_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Xw8BQHwD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bH3fBTi3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_siBIiLw7_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalPhasor sPhasor_0vxpduqX;
  SignalLine sLine_IbQRseQ5;
  SignalLine sLine_CFB57tOG;
  SignalTabhead sTabhead_I3ZJ8s1i;
  SignalTabread sTabread_NwbS72F7;
  SignalTabread sTabread_mMjlcZwU;
  SignalTabhead sTabhead_XowQl7sS;
  SignalTabread sTabread_jsbnNMEK;
  SignalTabread sTabread_njaEGgOw;
  SignalTabwrite sTabwrite_kovSpz9r;
  SignalRPole sRPole_6uErdXIM;
  SignalDel1 sDel1_Y0yL3Cl1;
  SignalTabread sTabread_wW3KMCVs;
  SignalTabwrite sTabwrite_t26L9f2C;
  SignalTabread sTabread_lbMhGGh8;
  SignalRPole sRPole_pdfEyZZf;
  SignalLine sLine_ivft9eEj;
  SignalLine sLine_X5KtKCoM;
  SignalTabread sTabread_G1SDi5ZH;
  SignalTabread sTabread_D6Yszqpj;
  SignalTabread sTabread_AKzQNmPk;
  SignalTabread sTabread_lRbL4hdp;
  SignalTabread sTabread_2MvsNWAi;
  SignalTabread sTabread_dU5YsroQ;
  SignalTabwrite sTabwrite_42ludZgk;
  SignalTabwrite sTabwrite_PQoVLLNo;
  SignalTabwrite sTabwrite_lu6EhYt8;
  SignalTabwrite sTabwrite_ELDdyV01;
  SignalTabwrite sTabwrite_03GQTMG4;
  SignalTabwrite sTabwrite_orbJMBl7;
  SignalTabread sTabread_rgWwA9DW;
  SignalRPole sRPole_ahftubtk;
  SignalTabread sTabread_3Ak4ouDU;
  SignalRPole sRPole_U2jGAiAx;
  SignalTabread sTabread_1pZDNPqC;
  SignalRPole sRPole_Ia2YN6SI;
  SignalTabwrite sTabwrite_GZPbtpSe;
  SignalTabwrite sTabwrite_oL7HH7At;
  SignalTabwrite sTabwrite_fmchOf5p;
  SignalTabwrite sTabwrite_rxM77lpU;
  SignalLine sLine_C3gtSON1;
  ControlVar cVar_cluz104w;
  ControlVar cVar_AD9WCCnh;
  ControlPack cPack_OeLRRMte;
  ControlBinop cBinop_rIIaJH8v;
  ControlVar cVar_ahNjGUMr;
  ControlPack cPack_PEhMOqG0;
  ControlVar cVar_l0pAHdj0;
  ControlVar cVar_YrggNKTg;
  ControlDelay cDelay_I7sd1bMA;
  ControlDelay cDelay_SEfwrYrw;
  ControlBinop cBinop_qpo70477;
  HvTable hTable_8ADo5qiG;
  ControlBinop cBinop_HeYLFzCd;
  ControlVar cVar_1mD8oCk9;
  ControlBinop cBinop_h3yqSZMw;
  ControlBinop cBinop_spqPlCOv;
  SignalVarf sVarf_TDHf8Amr;
  SignalVarf sVarf_g9hHyq0m;
  SignalVarf sVarf_5zTihDPy;
  ControlVar cVar_d88K8eWF;
  ControlBinop cBinop_VOnYMirm;
  ControlBinop cBinop_16tiqgOF;
  SignalVarf sVarf_vQAxcnNF;
  SignalVarf sVarf_GKDcIbr0;
  SignalVarf sVarf_wnp1tdI3;
  ControlBinop cBinop_ZzqV0Wrk;
  ControlBinop cBinop_z3q7wihp;
  ControlBinop cBinop_hW9n9UyI;
  ControlBinop cBinop_PjcqGZLb;
  ControlBinop cBinop_VbWwaabz;
  ControlBinop cBinop_kgEd5FjH;
  ControlBinop cBinop_ZOqCrqcW;
  ControlBinop cBinop_hE7ZfJhP;
  ControlBinop cBinop_IWvwelh8;
  SignalVarf sVarf_UYJxN8m4;
  ControlVar cVar_hA4fkERM;
  ControlBinop cBinop_0jABJO2R;
  ControlBinop cBinop_RlwBxr5n;
  ControlBinop cBinop_5ouTwwmN;
  ControlBinop cBinop_cwYgPxFR;
  ControlBinop cBinop_gjz5q2LE;
  ControlBinop cBinop_Y9LpSix2;
  ControlBinop cBinop_v1n9RbOe;
  SignalVarf sVarf_70I1lGSq;
  ControlBinop cBinop_6tz4Csag;
  ControlRandom cRandom_1VycPsHK;
  ControlSlice cSlice_j3y1it7M;
  ControlDelay cDelay_C3TAoQXZ;
  ControlVar cVar_QuhCQpwm;
  ControlBinop cBinop_vCucB2G2;
  ControlBinop cBinop_5PYXhRoO;
  ControlBinop cBinop_Wdt8ql6g;
  ControlTabhead cTabhead_f5scY1oh;
  ControlVar cVar_ZfGG7kUd;
  ControlDelay cDelay_7veAeliV;
  ControlDelay cDelay_ppEuWDOd;
  ControlBinop cBinop_j8ZJgMdB;
  ControlBinop cBinop_UdFuZ2oT;
  ControlBinop cBinop_X8y8pulQ;
  ControlBinop cBinop_xMRBQ0F0;
  ControlBinop cBinop_vq8Nevjs;
  ControlBinop cBinop_YxkxWfZT;
  ControlTabhead cTabhead_2zXlWrsb;
  ControlVar cVar_Sw6GbnAT;
  ControlDelay cDelay_DXoi3xNF;
  ControlDelay cDelay_QXGvgeGM;
  ControlBinop cBinop_XM62KSBn;
  ControlBinop cBinop_G0xilt08;
  ControlBinop cBinop_UVeXvTfP;
  ControlBinop cBinop_7c1eLwF9;
  ControlBinop cBinop_W7ZNk5qV;
  ControlBinop cBinop_RKFY2Or3;
  ControlTabhead cTabhead_Rx211Gl0;
  ControlVar cVar_wnPFyn0B;
  ControlDelay cDelay_xGdiGprP;
  ControlDelay cDelay_GPq6X1xj;
  ControlBinop cBinop_8JstMwXw;
  ControlBinop cBinop_G6xYtOEN;
  ControlBinop cBinop_CikmU2x1;
  ControlBinop cBinop_0PYOrqZY;
  ControlBinop cBinop_SLKi51Hy;
  ControlBinop cBinop_eE9xk2dd;
  ControlTabhead cTabhead_xMW0s7PV;
  ControlVar cVar_JiFE195Y;
  ControlDelay cDelay_v1UtFv5S;
  ControlDelay cDelay_jt08iaCM;
  ControlBinop cBinop_IVWZgiW8;
  ControlBinop cBinop_aXXh7TDd;
  ControlBinop cBinop_CJbQoirA;
  ControlBinop cBinop_NOVskrzd;
  ControlBinop cBinop_QpfRXW03;
  ControlBinop cBinop_C9ZgeSuI;
  ControlDelay cDelay_nQmcczef;
  ControlDelay cDelay_CF6yMHOm;
  ControlBinop cBinop_VNictWua;
  HvTable hTable_7P3o9gMy;
  ControlBinop cBinop_SDq1LMjP;
  ControlDelay cDelay_x5gKqtX9;
  ControlDelay cDelay_xXKLG6nr;
  ControlBinop cBinop_DByGilSJ;
  HvTable hTable_gs61gmfv;
  ControlBinop cBinop_SlNQPlFE;
  ControlDelay cDelay_1gsC74wu;
  ControlDelay cDelay_gqIkb1WM;
  ControlBinop cBinop_Jcgw7ocj;
  HvTable hTable_ISG38vW3;
  ControlBinop cBinop_ag1QM7qI;
  ControlDelay cDelay_N4lkxbed;
  ControlDelay cDelay_KQecCqRY;
  ControlBinop cBinop_ygwjhYho;
  HvTable hTable_tVWrUQip;
  ControlBinop cBinop_QubCm8Ky;
  ControlPack cPack_ysisArw1;
  ControlPack cPack_IMfhzYHs;
  ControlBinop cBinop_7Bgzmzco;
  ControlBinop cBinop_n5EYSupL;
  ControlVar cVar_2FIEZts5;
  ControlBinop cBinop_UhTa0DbQ;
  ControlBinop cBinop_7MFrD751;
  SignalVarf sVarf_7qWi6hNp;
  ControlBinop cBinop_a3uEsaFh;
  ControlBinop cBinop_4Oy6z3b7;
  ControlBinop cBinop_TjUt8cfW;
  SignalVarf sVarf_0uaubYgj;
  ControlVar cVar_Hnu0ImOb;
  ControlVar cVar_ZyF3XWg3;
  ControlVar cVar_rZczA09m;
  ControlVar cVar_D0IlWBbM;
  ControlIf cIf_sZVILnq5;
  ControlBinop cBinop_0oPYiTGS;
  ControlBinop cBinop_eOKuyQRq;
  ControlBinop cBinop_mCtb5K1s;
  ControlDelay cDelay_REx4CoTP;
  ControlDelay cDelay_NzN48K05;
  ControlBinop cBinop_PvYwtS1q;
  HvTable hTable_r2cmE7It;
  ControlBinop cBinop_M0pZcvnd;
  ControlTabhead cTabhead_SUKWcMMa;
  ControlVar cVar_f0Fq9lAy;
  ControlDelay cDelay_BYxoKq50;
  ControlDelay cDelay_z75OKMqg;
  ControlBinop cBinop_5vuMbhgD;
  ControlBinop cBinop_oVHK2658;
  ControlBinop cBinop_MWqPR4Jp;
  ControlBinop cBinop_qRrjtBu3;
  ControlBinop cBinop_VyPkTbxz;
  ControlBinop cBinop_c2h3kxVM;
  ControlDelay cDelay_SZH4f8vZ;
  ControlDelay cDelay_15vycgP4;
  ControlBinop cBinop_7EW0VPcG;
  HvTable hTable_URpUJA48;
  ControlBinop cBinop_E1BdOahe;
  ControlTabhead cTabhead_TDE7z6fi;
  ControlVar cVar_u1eOx5yP;
  ControlDelay cDelay_MRjbLZZT;
  ControlDelay cDelay_M81ncLR1;
  ControlBinop cBinop_VLODo76A;
  ControlBinop cBinop_9IAgwH0w;
  ControlBinop cBinop_pX8CSwhn;
  ControlBinop cBinop_wCK7l7hX;
  ControlBinop cBinop_O6A1elOr;
  ControlBinop cBinop_l1G10hPH;
  ControlDelay cDelay_M7cDhrrN;
  ControlDelay cDelay_ZHFh339D;
  ControlBinop cBinop_8Zh7iMWx;
  HvTable hTable_TkDvhtvi;
  ControlBinop cBinop_3pTvB4U4;
  ControlTabhead cTabhead_MnyGpRp5;
  ControlVar cVar_a0vya4bC;
  ControlDelay cDelay_JhObY49w;
  ControlDelay cDelay_iBbI1zou;
  ControlBinop cBinop_lP2J3Xln;
  ControlBinop cBinop_xfeu4pQ8;
  ControlBinop cBinop_DAguFkuB;
  ControlBinop cBinop_8zxIf878;
  ControlBinop cBinop_qOVVG4wy;
  ControlBinop cBinop_pL8yMn1I;
  ControlDelay cDelay_Inzg5KFv;
  ControlDelay cDelay_VzKYvr8f;
  ControlBinop cBinop_RgM3gUIb;
  HvTable hTable_0ajfZMEY;
  ControlBinop cBinop_faJcnOfn;
  ControlTabhead cTabhead_Ni9gslk7;
  ControlVar cVar_CIS60FzH;
  ControlDelay cDelay_CUvzfoGB;
  ControlDelay cDelay_igQF6fRj;
  ControlBinop cBinop_QknBrir8;
  ControlBinop cBinop_dlVXgQl7;
  ControlBinop cBinop_zJeU2Lmk;
  ControlBinop cBinop_8cOKDLtW;
  ControlBinop cBinop_Vu6lCv1u;
  ControlBinop cBinop_yr7jGdyo;
  ControlDelay cDelay_qhv4rS7t;
  ControlDelay cDelay_5zfXzVyg;
  ControlBinop cBinop_wjbB7M3A;
  HvTable hTable_FrHixOBB;
  ControlBinop cBinop_p9JzKQ5M;
  ControlTabhead cTabhead_6kLrEwM8;
  ControlVar cVar_hrAX5gyS;
  ControlDelay cDelay_4WRJV5qe;
  ControlDelay cDelay_qiGANPvY;
  ControlBinop cBinop_Q1V4ts1Z;
  ControlBinop cBinop_E4wNv3dh;
  ControlBinop cBinop_AsTRbLJH;
  ControlBinop cBinop_D0pkayHU;
  ControlBinop cBinop_5q4fstTv;
  ControlBinop cBinop_6ScYRVsm;
  ControlDelay cDelay_Sl7JcsbL;
  ControlDelay cDelay_BdzT4Pzp;
  ControlBinop cBinop_sRaf3js8;
  HvTable hTable_ZO1cJ2EM;
  ControlBinop cBinop_H5JjMAEB;
  ControlTabhead cTabhead_FBCmFB60;
  ControlVar cVar_0QKLlUiN;
  ControlDelay cDelay_RAX58SO3;
  ControlDelay cDelay_IlowjLH7;
  ControlBinop cBinop_zUHCVro6;
  ControlBinop cBinop_PRvAPGQx;
  ControlBinop cBinop_2QkhpdKV;
  ControlBinop cBinop_nWWXZpXL;
  ControlBinop cBinop_2SvDVIOO;
  ControlBinop cBinop_c1tV8sSn;
  ControlVar cVar_2KsF02Dp;
  ControlVar cVar_k39vTacD;
  ControlPack cPack_Mb24BZRo;
  ControlVar cVar_48osh9i0;
  ControlBinop cBinop_gsUblF5C;
  ControlBinop cBinop_F6cr4ED5;
  SignalVarf sVarf_rO40fw0f;
  ControlBinop cBinop_aBehNtXp;
  ControlBinop cBinop_gUJGm7dg;
  ControlBinop cBinop_ive3cAy3;
  SignalVarf sVarf_CNywrojy;
  ControlVar cVar_C6Wo7gO9;
  ControlBinop cBinop_Sy7SfvzH;
  ControlBinop cBinop_TKeyVaqw;
  SignalVarf sVarf_FWHcOkKR;
  ControlBinop cBinop_80jkNOiO;
  ControlBinop cBinop_DZ9kwMSy;
  ControlBinop cBinop_aQjsRobr;
  SignalVarf sVarf_IY16KPQ7;
  ControlVar cVar_rKb5XsuP;
  ControlBinop cBinop_cOBDJjLn;
  ControlBinop cBinop_rqWce3PV;
  SignalVarf sVarf_qBbLSUUO;
  ControlBinop cBinop_HiMV5gQl;
  ControlBinop cBinop_CgSrjonQ;
  ControlBinop cBinop_nmp8Y2tz;
  SignalVarf sVarf_rTrv0Ji8;
  ControlBinop cBinop_QqMx5MH8;
  ControlBinop cBinop_oNDn597y;
  ControlBinop cBinop_48NfRWTZ;
  ControlDelay cDelay_0FCbEKII;
  ControlVar cVar_RlrjzoPj;
  ControlBinop cBinop_OSqxxAiv;
  ControlBinop cBinop_pJv9GBgR;
  ControlBinop cBinop_G2BQxeqd;
  ControlVar cVar_eNNMsWrr;
  ControlVar cVar_K8GWTKZM;
  ControlIf cIf_1rtvzaaV;
  ControlBinop cBinop_lzVNPVG9;
  ControlDelay cDelay_Q0x28SwE;
  ControlDelay cDelay_565aod2N;
  ControlBinop cBinop_khLZ1gxD;
  HvTable hTable_LsKykipe;
  ControlBinop cBinop_SHG5UcaM;
  ControlTabhead cTabhead_2OmiD6Le;
  ControlVar cVar_THWGNupx;
  ControlDelay cDelay_QDyiDah0;
  ControlDelay cDelay_PKH42TsK;
  ControlBinop cBinop_gAr1GLCQ;
  ControlBinop cBinop_QDLXB31W;
  ControlBinop cBinop_1us3fHGC;
  ControlBinop cBinop_4A9d8Djz;
  ControlBinop cBinop_bGqrCd6D;
  ControlBinop cBinop_LqkvS2rw;
  ControlVar cVar_zfMBZTj6;
  ControlVar cVar_8GXBPUWE;
  ControlVar cVar_va9MzQbx;
  ControlVar cVar_f5SbFhSj;
  ControlVar cVar_KSukTfiC;
  ControlVar cVar_bwQTItBM;
  ControlIf cIf_3iprGRq9;
  ControlBinop cBinop_dJrQvQdV;
  ControlVar cVar_U3AlKKG7;
  ControlIf cIf_mNyH3nOO;
  ControlBinop cBinop_wQQSqfX8;
  ControlSlice cSlice_7CV6lEbb;
  ControlSlice cSlice_bCfXIFPf;
  ControlVar cVar_Bfw6B9uT;
  ControlIf cIf_4NUSv0eF;
  ControlBinop cBinop_wlC0sROc;
  ControlIf cIf_1l1qjTrq;
  ControlIf cIf_hqOg6l6l;
  ControlIf cIf_hYv6pzV2;
  ControlIf cIf_utX0ySsi;
  ControlIf cIf_igFfkiHj;
  SignalVarf sVarf_MaqAsMBv;
  ControlBinop cBinop_o4bIfA3m;
  ControlBinop cBinop_WsLJXTAZ;
  ControlBinop cBinop_bj1jNnXG;
  ControlBinop cBinop_mh2vjejf;
  SignalVarf sVarf_PJkcdRpd;
  ControlBinop cBinop_qKiZN8Ky;
  ControlBinop cBinop_y9yHWULy;
  SignalVarf sVarf_WN7iMX2B;
  SignalVarf sVarf_HQxI5Asa;
  ControlBinop cBinop_tzY93vAF;
  ControlBinop cBinop_NTfEdikI;
  ControlBinop cBinop_n5UBUUiL;
  ControlBinop cBinop_BAj5U73K;
  ControlBinop cBinop_RGLCsVDo;
  ControlBinop cBinop_gbw15IyB;
  ControlBinop cBinop_UAujDSWU;
  ControlBinop cBinop_ECDOjZOn;
  ControlBinop cBinop_vrOWX2JR;
  ControlBinop cBinop_T3hVmpSb;
  ControlBinop cBinop_nF6zMUT3;
  ControlBinop cBinop_olJ9m7DJ;
  ControlBinop cBinop_CnRukJ3q;
};

#endif // _HEAVY_CONTEXT_CHAFFVERB_HPP_
