/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_ChaffVerb.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_ChaffVerb *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_ChaffVerb_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_ChaffVerb));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_ChaffVerb(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_ChaffVerb_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_ChaffVerb();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_ChaffVerb::Heavy_ChaffVerb(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sPhasor_k_init(&sPhasor_0vxpduqX, 0.0f, sampleRate);
  numBytes += sLine_init(&sLine_IbQRseQ5);
  numBytes += sLine_init(&sLine_CFB57tOG);
  numBytes += sTabhead_init(&sTabhead_I3ZJ8s1i, &hTable_8ADo5qiG);
  numBytes += sTabread_init(&sTabread_NwbS72F7, &hTable_8ADo5qiG, false);
  numBytes += sTabread_init(&sTabread_mMjlcZwU, &hTable_8ADo5qiG, false);
  numBytes += sTabhead_init(&sTabhead_XowQl7sS, &hTable_8ADo5qiG);
  numBytes += sTabread_init(&sTabread_jsbnNMEK, &hTable_8ADo5qiG, false);
  numBytes += sTabread_init(&sTabread_njaEGgOw, &hTable_8ADo5qiG, false);
  numBytes += sTabwrite_init(&sTabwrite_kovSpz9r, &hTable_8ADo5qiG);
  numBytes += sRPole_init(&sRPole_6uErdXIM);
  numBytes += sDel1_init(&sDel1_Y0yL3Cl1);
  numBytes += sTabread_init(&sTabread_wW3KMCVs, &hTable_LsKykipe, true);
  numBytes += sTabwrite_init(&sTabwrite_t26L9f2C, &hTable_LsKykipe);
  numBytes += sTabread_init(&sTabread_lbMhGGh8, &hTable_7P3o9gMy, true);
  numBytes += sRPole_init(&sRPole_pdfEyZZf);
  numBytes += sLine_init(&sLine_ivft9eEj);
  numBytes += sLine_init(&sLine_X5KtKCoM);
  numBytes += sTabread_init(&sTabread_G1SDi5ZH, &hTable_r2cmE7It, true);
  numBytes += sTabread_init(&sTabread_D6Yszqpj, &hTable_URpUJA48, true);
  numBytes += sTabread_init(&sTabread_AKzQNmPk, &hTable_TkDvhtvi, true);
  numBytes += sTabread_init(&sTabread_lRbL4hdp, &hTable_0ajfZMEY, true);
  numBytes += sTabread_init(&sTabread_2MvsNWAi, &hTable_ZO1cJ2EM, true);
  numBytes += sTabread_init(&sTabread_dU5YsroQ, &hTable_FrHixOBB, true);
  numBytes += sTabwrite_init(&sTabwrite_42ludZgk, &hTable_r2cmE7It);
  numBytes += sTabwrite_init(&sTabwrite_PQoVLLNo, &hTable_URpUJA48);
  numBytes += sTabwrite_init(&sTabwrite_lu6EhYt8, &hTable_TkDvhtvi);
  numBytes += sTabwrite_init(&sTabwrite_ELDdyV01, &hTable_0ajfZMEY);
  numBytes += sTabwrite_init(&sTabwrite_03GQTMG4, &hTable_FrHixOBB);
  numBytes += sTabwrite_init(&sTabwrite_orbJMBl7, &hTable_ZO1cJ2EM);
  numBytes += sTabread_init(&sTabread_rgWwA9DW, &hTable_gs61gmfv, true);
  numBytes += sRPole_init(&sRPole_ahftubtk);
  numBytes += sTabread_init(&sTabread_3Ak4ouDU, &hTable_ISG38vW3, true);
  numBytes += sRPole_init(&sRPole_U2jGAiAx);
  numBytes += sTabread_init(&sTabread_1pZDNPqC, &hTable_tVWrUQip, true);
  numBytes += sRPole_init(&sRPole_Ia2YN6SI);
  numBytes += sTabwrite_init(&sTabwrite_GZPbtpSe, &hTable_7P3o9gMy);
  numBytes += sTabwrite_init(&sTabwrite_oL7HH7At, &hTable_gs61gmfv);
  numBytes += sTabwrite_init(&sTabwrite_fmchOf5p, &hTable_ISG38vW3);
  numBytes += sTabwrite_init(&sTabwrite_rxM77lpU, &hTable_tVWrUQip);
  numBytes += sLine_init(&sLine_C3gtSON1);
  numBytes += cVar_init_f(&cVar_cluz104w, 0.0f);
  numBytes += cVar_init_f(&cVar_AD9WCCnh, 0.0f);
  numBytes += cPack_init(&cPack_OeLRRMte, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_ahNjGUMr, 0.0f);
  numBytes += cPack_init(&cPack_PEhMOqG0, 2, 0.0f, 200.0f);
  numBytes += cVar_init_f(&cVar_l0pAHdj0, 0.0f);
  numBytes += cVar_init_f(&cVar_YrggNKTg, 0.0f);
  numBytes += cDelay_init(this, &cDelay_I7sd1bMA, 0.0f);
  numBytes += cDelay_init(this, &cDelay_SEfwrYrw, 0.0f);
  numBytes += hTable_init(&hTable_8ADo5qiG, 256);
  numBytes += cVar_init_s(&cVar_1mD8oCk9, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_TDHf8Amr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_g9hHyq0m, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5zTihDPy, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_d88K8eWF, "del-1002-shifter");
  numBytes += sVarf_init(&sVarf_vQAxcnNF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GKDcIbr0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wnp1tdI3, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_ZzqV0Wrk, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_UYJxN8m4, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_hA4fkERM, 0.0f);
  numBytes += cBinop_init(&cBinop_v1n9RbOe, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_70I1lGSq, 0.0f, 0.0f, false);
  numBytes += cRandom_init(&cRandom_1VycPsHK, 361517857);
  numBytes += cSlice_init(&cSlice_j3y1it7M, 1, 1);
  numBytes += cDelay_init(this, &cDelay_C3TAoQXZ, 0.0f);
  numBytes += cVar_init_f(&cVar_QuhCQpwm, 5.0f);
  numBytes += cBinop_init(&cBinop_Wdt8ql6g, 0.0f); // __mul
  numBytes += cTabhead_init(&cTabhead_f5scY1oh, &hTable_7P3o9gMy);
  numBytes += cVar_init_s(&cVar_ZfGG7kUd, "del-1052-del1");
  numBytes += cDelay_init(this, &cDelay_7veAeliV, 58.6435f);
  numBytes += cDelay_init(this, &cDelay_ppEuWDOd, 0.0f);
  numBytes += cBinop_init(&cBinop_j8ZJgMdB, 58.6435f); // __mul
  numBytes += cBinop_init(&cBinop_X8y8pulQ, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_xMRBQ0F0, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_YxkxWfZT, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_2zXlWrsb, &hTable_gs61gmfv);
  numBytes += cVar_init_s(&cVar_Sw6GbnAT, "del-1052-del2");
  numBytes += cDelay_init(this, &cDelay_DXoi3xNF, 69.4325f);
  numBytes += cDelay_init(this, &cDelay_QXGvgeGM, 0.0f);
  numBytes += cBinop_init(&cBinop_XM62KSBn, 69.4325f); // __mul
  numBytes += cBinop_init(&cBinop_UVeXvTfP, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_7c1eLwF9, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_RKFY2Or3, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_Rx211Gl0, &hTable_ISG38vW3);
  numBytes += cVar_init_s(&cVar_wnPFyn0B, "del-1052-del3");
  numBytes += cDelay_init(this, &cDelay_xGdiGprP, 74.5234f);
  numBytes += cDelay_init(this, &cDelay_GPq6X1xj, 0.0f);
  numBytes += cBinop_init(&cBinop_8JstMwXw, 74.5234f); // __mul
  numBytes += cBinop_init(&cBinop_CikmU2x1, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_0PYOrqZY, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_eE9xk2dd, 0.0f); // __sub
  numBytes += cTabhead_init(&cTabhead_xMW0s7PV, &hTable_tVWrUQip);
  numBytes += cVar_init_s(&cVar_JiFE195Y, "del-1052-del4");
  numBytes += cDelay_init(this, &cDelay_v1UtFv5S, 86.1244f);
  numBytes += cDelay_init(this, &cDelay_jt08iaCM, 0.0f);
  numBytes += cBinop_init(&cBinop_IVWZgiW8, 86.1244f); // __mul
  numBytes += cBinop_init(&cBinop_CJbQoirA, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_NOVskrzd, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_C9ZgeSuI, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_nQmcczef, 0.0f);
  numBytes += cDelay_init(this, &cDelay_CF6yMHOm, 0.0f);
  numBytes += hTable_init(&hTable_7P3o9gMy, 256);
  numBytes += cDelay_init(this, &cDelay_x5gKqtX9, 0.0f);
  numBytes += cDelay_init(this, &cDelay_xXKLG6nr, 0.0f);
  numBytes += hTable_init(&hTable_gs61gmfv, 256);
  numBytes += cDelay_init(this, &cDelay_1gsC74wu, 0.0f);
  numBytes += cDelay_init(this, &cDelay_gqIkb1WM, 0.0f);
  numBytes += hTable_init(&hTable_ISG38vW3, 256);
  numBytes += cDelay_init(this, &cDelay_N4lkxbed, 0.0f);
  numBytes += cDelay_init(this, &cDelay_KQecCqRY, 0.0f);
  numBytes += hTable_init(&hTable_tVWrUQip, 256);
  numBytes += cPack_init(&cPack_ysisArw1, 2, 0.0f, 30.0f);
  numBytes += cPack_init(&cPack_IMfhzYHs, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_2FIEZts5, 22050.0f);
  numBytes += cBinop_init(&cBinop_UhTa0DbQ, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_7qWi6hNp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0uaubYgj, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Hnu0ImOb, 0.0f);
  numBytes += cVar_init_f(&cVar_ZyF3XWg3, 0.0f);
  numBytes += cVar_init_f(&cVar_rZczA09m, 0.0f);
  numBytes += cVar_init_f(&cVar_D0IlWBbM, 0.0f);
  numBytes += cIf_init(&cIf_sZVILnq5, false);
  numBytes += cDelay_init(this, &cDelay_REx4CoTP, 0.0f);
  numBytes += cDelay_init(this, &cDelay_NzN48K05, 0.0f);
  numBytes += hTable_init(&hTable_r2cmE7It, 256);
  numBytes += cTabhead_init(&cTabhead_SUKWcMMa, &hTable_r2cmE7It);
  numBytes += cVar_init_s(&cVar_f0Fq9lAy, "del-1052-ref1");
  numBytes += cDelay_init(this, &cDelay_BYxoKq50, 43.5337f);
  numBytes += cDelay_init(this, &cDelay_z75OKMqg, 0.0f);
  numBytes += cBinop_init(&cBinop_5vuMbhgD, 43.5337f); // __mul
  numBytes += cBinop_init(&cBinop_MWqPR4Jp, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_qRrjtBu3, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_c2h3kxVM, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_SZH4f8vZ, 0.0f);
  numBytes += cDelay_init(this, &cDelay_15vycgP4, 0.0f);
  numBytes += hTable_init(&hTable_URpUJA48, 256);
  numBytes += cTabhead_init(&cTabhead_TDE7z6fi, &hTable_URpUJA48);
  numBytes += cVar_init_s(&cVar_u1eOx5yP, "del-1052-ref2");
  numBytes += cDelay_init(this, &cDelay_MRjbLZZT, 25.796f);
  numBytes += cDelay_init(this, &cDelay_M81ncLR1, 0.0f);
  numBytes += cBinop_init(&cBinop_VLODo76A, 25.796f); // __mul
  numBytes += cBinop_init(&cBinop_pX8CSwhn, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_wCK7l7hX, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_l1G10hPH, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_M7cDhrrN, 0.0f);
  numBytes += cDelay_init(this, &cDelay_ZHFh339D, 0.0f);
  numBytes += hTable_init(&hTable_TkDvhtvi, 256);
  numBytes += cTabhead_init(&cTabhead_MnyGpRp5, &hTable_TkDvhtvi);
  numBytes += cVar_init_s(&cVar_a0vya4bC, "del-1052-ref3");
  numBytes += cDelay_init(this, &cDelay_JhObY49w, 19.392f);
  numBytes += cDelay_init(this, &cDelay_iBbI1zou, 0.0f);
  numBytes += cBinop_init(&cBinop_lP2J3Xln, 19.392f); // __mul
  numBytes += cBinop_init(&cBinop_DAguFkuB, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_8zxIf878, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_pL8yMn1I, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_Inzg5KFv, 0.0f);
  numBytes += cDelay_init(this, &cDelay_VzKYvr8f, 0.0f);
  numBytes += hTable_init(&hTable_0ajfZMEY, 256);
  numBytes += cTabhead_init(&cTabhead_Ni9gslk7, &hTable_0ajfZMEY);
  numBytes += cVar_init_s(&cVar_CIS60FzH, "del-1052-ref4");
  numBytes += cDelay_init(this, &cDelay_CUvzfoGB, 16.364f);
  numBytes += cDelay_init(this, &cDelay_igQF6fRj, 0.0f);
  numBytes += cBinop_init(&cBinop_QknBrir8, 16.364f); // __mul
  numBytes += cBinop_init(&cBinop_zJeU2Lmk, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_8cOKDLtW, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_yr7jGdyo, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_qhv4rS7t, 0.0f);
  numBytes += cDelay_init(this, &cDelay_5zfXzVyg, 0.0f);
  numBytes += hTable_init(&hTable_FrHixOBB, 256);
  numBytes += cTabhead_init(&cTabhead_6kLrEwM8, &hTable_FrHixOBB);
  numBytes += cVar_init_s(&cVar_hrAX5gyS, "del-1052-ref6");
  numBytes += cDelay_init(this, &cDelay_4WRJV5qe, 4.2546f);
  numBytes += cDelay_init(this, &cDelay_qiGANPvY, 0.0f);
  numBytes += cBinop_init(&cBinop_Q1V4ts1Z, 4.2546f); // __mul
  numBytes += cBinop_init(&cBinop_AsTRbLJH, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_D0pkayHU, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_6ScYRVsm, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_Sl7JcsbL, 0.0f);
  numBytes += cDelay_init(this, &cDelay_BdzT4Pzp, 0.0f);
  numBytes += hTable_init(&hTable_ZO1cJ2EM, 256);
  numBytes += cTabhead_init(&cTabhead_FBCmFB60, &hTable_ZO1cJ2EM);
  numBytes += cVar_init_s(&cVar_0QKLlUiN, "del-1052-ref5");
  numBytes += cDelay_init(this, &cDelay_RAX58SO3, 7.645f);
  numBytes += cDelay_init(this, &cDelay_IlowjLH7, 0.0f);
  numBytes += cBinop_init(&cBinop_zUHCVro6, 7.645f); // __mul
  numBytes += cBinop_init(&cBinop_2QkhpdKV, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_nWWXZpXL, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_c1tV8sSn, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_2KsF02Dp, 0.0f);
  numBytes += cVar_init_f(&cVar_k39vTacD, 0.0f);
  numBytes += cPack_init(&cPack_Mb24BZRo, 2, 0.0f, 50.0f);
  numBytes += cVar_init_f(&cVar_48osh9i0, 22050.0f);
  numBytes += cBinop_init(&cBinop_gsUblF5C, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_rO40fw0f, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CNywrojy, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_C6Wo7gO9, 22050.0f);
  numBytes += cBinop_init(&cBinop_Sy7SfvzH, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_FWHcOkKR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IY16KPQ7, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_rKb5XsuP, 22050.0f);
  numBytes += cBinop_init(&cBinop_cOBDJjLn, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_qBbLSUUO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rTrv0Ji8, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_0FCbEKII, 0.0f);
  numBytes += cVar_init_f(&cVar_RlrjzoPj, 1000.0f);
  numBytes += cBinop_init(&cBinop_G2BQxeqd, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_eNNMsWrr, 0.0f);
  numBytes += cVar_init_f(&cVar_K8GWTKZM, 0.0f);
  numBytes += cIf_init(&cIf_1rtvzaaV, false);
  numBytes += cDelay_init(this, &cDelay_Q0x28SwE, 0.0f);
  numBytes += cDelay_init(this, &cDelay_565aod2N, 0.0f);
  numBytes += hTable_init(&hTable_LsKykipe, 256);
  numBytes += cTabhead_init(&cTabhead_2OmiD6Le, &hTable_LsKykipe);
  numBytes += cVar_init_s(&cVar_THWGNupx, "del-1001-del1");
  numBytes += cDelay_init(this, &cDelay_QDyiDah0, 150.0f);
  numBytes += cDelay_init(this, &cDelay_PKH42TsK, 0.0f);
  numBytes += cBinop_init(&cBinop_gAr1GLCQ, 150.0f); // __mul
  numBytes += cBinop_init(&cBinop_1us3fHGC, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_4A9d8Djz, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_LqkvS2rw, 0.0f); // __sub
  numBytes += cVar_init_f(&cVar_zfMBZTj6, 0.0f);
  numBytes += cVar_init_f(&cVar_8GXBPUWE, 0.0f);
  numBytes += cVar_init_f(&cVar_va9MzQbx, 0.0f);
  numBytes += cVar_init_f(&cVar_f5SbFhSj, 0.0f);
  numBytes += cVar_init_f(&cVar_KSukTfiC, 0.0f);
  numBytes += cVar_init_f(&cVar_bwQTItBM, 0.0f);
  numBytes += cIf_init(&cIf_3iprGRq9, false);
  numBytes += cVar_init_f(&cVar_U3AlKKG7, 0.0f);
  numBytes += cIf_init(&cIf_mNyH3nOO, false);
  numBytes += cSlice_init(&cSlice_7CV6lEbb, 1, -1);
  numBytes += cSlice_init(&cSlice_bCfXIFPf, 1, -1);
  numBytes += cVar_init_f(&cVar_Bfw6B9uT, 0.0f);
  numBytes += cIf_init(&cIf_4NUSv0eF, false);
  numBytes += cBinop_init(&cBinop_wlC0sROc, 0.0f); // __neq
  numBytes += cIf_init(&cIf_1l1qjTrq, false);
  numBytes += cIf_init(&cIf_hqOg6l6l, false);
  numBytes += cIf_init(&cIf_hYv6pzV2, false);
  numBytes += cIf_init(&cIf_utX0ySsi, true);
  numBytes += cIf_init(&cIf_igFfkiHj, false);
  numBytes += sVarf_init(&sVarf_MaqAsMBv, 1.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_bj1jNnXG, 4.0f); // __unimod
  numBytes += sVarf_init(&sVarf_PJkcdRpd, 0.1f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_qKiZN8Ky, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_y9yHWULy, 0.0f); // __add
  numBytes += sVarf_init(&sVarf_WN7iMX2B, 0.65f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HQxI5Asa, 0.55f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_NTfEdikI, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_vrOWX2JR, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_T3hVmpSb, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_nF6zMUT3, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_olJ9m7DJ, 1.0f); // __mul
  numBytes += cBinop_init(&cBinop_CnRukJ3q, 0.0f); // __add
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_ChaffVerb::~Heavy_ChaffVerb() {
  cPack_free(&cPack_OeLRRMte);
  cPack_free(&cPack_PEhMOqG0);
  hTable_free(&hTable_8ADo5qiG);
  hTable_free(&hTable_7P3o9gMy);
  hTable_free(&hTable_gs61gmfv);
  hTable_free(&hTable_ISG38vW3);
  hTable_free(&hTable_tVWrUQip);
  cPack_free(&cPack_ysisArw1);
  cPack_free(&cPack_IMfhzYHs);
  hTable_free(&hTable_r2cmE7It);
  hTable_free(&hTable_URpUJA48);
  hTable_free(&hTable_TkDvhtvi);
  hTable_free(&hTable_0ajfZMEY);
  hTable_free(&hTable_FrHixOBB);
  hTable_free(&hTable_ZO1cJ2EM);
  cPack_free(&cPack_Mb24BZRo);
  hTable_free(&hTable_LsKykipe);
}

HvTable *Heavy_ChaffVerb::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xA1445E2C: return &hTable_8ADo5qiG; // del-1002-shifter
    case 0xAAA0EB60: return &hTable_7P3o9gMy; // del-1052-del1
    case 0xA2AC524D: return &hTable_gs61gmfv; // del-1052-del2
    case 0xE36A35B: return &hTable_ISG38vW3; // del-1052-del3
    case 0x48CE0509: return &hTable_tVWrUQip; // del-1052-del4
    case 0xE34D6E72: return &hTable_r2cmE7It; // del-1052-ref1
    case 0x6A1027AB: return &hTable_URpUJA48; // del-1052-ref2
    case 0xA37C6D49: return &hTable_TkDvhtvi; // del-1052-ref3
    case 0xCEFE5FE5: return &hTable_0ajfZMEY; // del-1052-ref4
    case 0x48EB8BBB: return &hTable_FrHixOBB; // del-1052-ref6
    case 0xCC6F73D5: return &hTable_ZO1cJ2EM; // del-1052-ref5
    case 0xED65564F: return &hTable_LsKykipe; // del-1001-del1
    default: return nullptr;
  }
}

void Heavy_ChaffVerb::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x1F30993F: { // A__LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uvlfLd9S_sendMessage);
      break;
    }
    case 0x1A2B8E9F: { // A__LFO_Steps_Scale__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_k4Rs6aUA_sendMessage);
      break;
    }
    case 0xBE3344C8: { // A__LFO_Steps__Type2
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mNxTGuNK_sendMessage);
      break;
    }
    case 0x7369936E: { // A__LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_siBIiLw7_sendMessage);
      break;
    }
    case 0xD64CFD23: { // A__LFO_type
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pzvHUdR0_sendMessage);
      break;
    }
    case 0x51447E19: { // B__General_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_q40WJUvW_sendMessage);
      break;
    }
    case 0xA10FCFC4: { // B__General_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0ltOgt84_sendMessage);
      break;
    }
    case 0x7EFB8E46: { // C__Random_LFO_Offset
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JeZIaYS1_sendMessage);
      break;
    }
    case 0xE6223016: { // C__Random_LFO_Period
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0yyTzYtm_sendMessage);
      break;
    }
    case 0x3281900D: { // C__Random_LFO_Scale
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_e6amkfJu_sendMessage);
      break;
    }
    case 0x6150BC53: { // C__Random_LFO_Switch
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aHUlOjBN_sendMessage);
      break;
    }
    case 0x9CBB1BF3: { // D__Shift_Microtone
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_w4g9ny8C_sendMessage);
      break;
    }
    case 0x4439D71: { // D__Shift_Transpose
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PMmqFmxH_sendMessage);
      break;
    }
    case 0x890283C2: { // E__Fx_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3PvcGdss_sendMessage);
      break;
    }
    case 0x12962685: { // E__HiPass_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IHGoGECn_sendMessage);
      break;
    }
    case 0x183CFEE5: { // E__Shift_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cbDZKIdA_sendMessage);
      break;
    }
    case 0x57FF40DB: { // E__Shift_Window
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gTLuhfEZ_sendMessage);
      break;
    }
    case 0x69A91334: { // F__FX_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bH3fBTi3_sendMessage);
      break;
    }
    case 0x68D029F7: { // F__FX_Delay_Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Xw8BQHwD_sendMessage);
      break;
    }
    case 0xD63693D0: { // Mix__Dry_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QarmNs34_sendMessage);
      break;
    }
    case 0x1FC3C02C: { // Mix__Dry_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aSHpKxhm_sendMessage);
      break;
    }
    case 0x58653D84: { // Mix__Reverb_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_F2guKTqU_sendMessage);
      break;
    }
    case 0xE764F673: { // Mix__Reverb_Vol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_70mwynwG_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zVgv6CPY_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_ChaffVerb::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "A__LFO_Period";
        info->hash = 0x1F30993F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 1: {
        info->name = "A__LFO_Steps_Scale__Type2";
        info->hash = 0x1A2B8E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -5.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "A__LFO_Steps__Type2";
        info->hash = 0xBE3344C8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 10.0f;
        info->defaultVal = 4.0f;
        break;
      }
      case 3: {
        info->name = "A__LFO_Switch";
        info->hash = 0x7369936E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "A__LFO_type";
        info->hash = 0xD64CFD23;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2.99f;
        info->defaultVal = 0.0f;
        break;
      }
      case 5: {
        info->name = "B__General_Offset";
        info->hash = 0x51447E19;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 6: {
        info->name = "B__General_Scale";
        info->hash = 0xA10FCFC4;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "C__Random_LFO_Offset";
        info->hash = 0x7EFB8E46;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -2.0f;
        info->maxVal = 2.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "C__Random_LFO_Period";
        info->hash = 0xE6223016;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1500.0f;
        break;
      }
      case 9: {
        info->name = "C__Random_LFO_Scale";
        info->hash = 0x3281900D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -7.0f;
        info->maxVal = 7.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "C__Random_LFO_Switch";
        info->hash = 0x6150BC53;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 11: {
        info->name = "D__Shift_Microtone";
        info->hash = 0x9CBB1BF3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -1.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "D__Shift_Transpose";
        info->hash = 0x4439D71;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -36.0f;
        info->maxVal = 36.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "E__Fx_Level";
        info->hash = 0x890283C2;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.7f;
        break;
      }
      case 14: {
        info->name = "E__HiPass_Freq";
        info->hash = 0x12962685;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 100.0f;
        info->maxVal = 2500.0f;
        info->defaultVal = 800.0f;
        break;
      }
      case 15: {
        info->name = "E__Shift_Delay";
        info->hash = 0x183CFEE5;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 500.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "E__Shift_Window";
        info->hash = 0x57FF40DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 3500.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 17: {
        info->name = "F__FX_Delay";
        info->hash = 0x69A91334;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 2000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 18: {
        info->name = "F__FX_Delay_Feedback";
        info->hash = 0x68D029F7;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.97f;
        info->defaultVal = 0.65f;
        break;
      }
      case 19: {
        info->name = "Mix__Dry_Mix";
        info->hash = 0xD63693D0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.45f;
        break;
      }
      case 20: {
        info->name = "Mix__Dry_Vol";
        info->hash = 0x1FC3C02C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.1f;
        break;
      }
      case 21: {
        info->name = "Mix__Reverb_Level";
        info->hash = 0x58653D84;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.85f;
        break;
      }
      case 22: {
        info->name = "Mix__Reverb_Vol";
        info->hash = 0xE764F673;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.5f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 23;
}



/*
 * Send Function Implementations
 */


void Heavy_ChaffVerb::cVar_cluz104w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.05776f, 0, m, &cBinop_PjcqGZLb_sendMessage);
}

void Heavy_ChaffVerb::cVar_AD9WCCnh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_ZOqCrqcW_sendMessage);
}

void Heavy_ChaffVerb::cPack_OeLRRMte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_IbQRseQ5, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_KIegRoR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ahNjGUMr, 0, m, &cVar_ahNjGUMr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rIIaJH8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_EXP, m, &cUnop_KIegRoR1_sendMessage);
}

void Heavy_ChaffVerb::cVar_ahNjGUMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_hW9n9UyI_sendMessage);
}

void Heavy_ChaffVerb::cPack_PEhMOqG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_CFB57tOG, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_l0pAHdj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.5f, 0, m, &cBinop_kgEd5FjH_sendMessage);
}

void Heavy_ChaffVerb::cVar_YrggNKTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_0vxpduqX, 0, m);
}

void Heavy_ChaffVerb::cMsg_xiyIUFDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dMKjpoG3_sendMessage);
}

void Heavy_ChaffVerb::cSystem_dMKjpoG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_HeYLFzCd_sendMessage);
}

void Heavy_ChaffVerb::cDelay_I7sd1bMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_I7sd1bMA, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SEfwrYrw, 0, m, &cDelay_SEfwrYrw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_I7sd1bMA, 0, m, &cDelay_I7sd1bMA_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_kovSpz9r, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_SEfwrYrw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SEfwrYrw, m);
  cMsg_152DjYlZ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_88WNRSlm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_PlHESZDA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_qpo70477_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pPPXFtdL_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_8ADo5qiG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RI1gwrcJ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_I7sd1bMA, 2, m, &cDelay_I7sd1bMA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2UMtDSzr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pPPXFtdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_8ADo5qiG, 0, m, &hTable_8ADo5qiG_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HeYLFzCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_qpo70477_sendMessage);
}

void Heavy_ChaffVerb::cMsg_152DjYlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_8ADo5qiG, 0, m, &hTable_8ADo5qiG_sendMessage);
}

void Heavy_ChaffVerb::cCast_2UMtDSzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_I7sd1bMA, 0, m, &cDelay_I7sd1bMA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_RI1gwrcJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_SEfwrYrw, 2, m, &cDelay_SEfwrYrw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_PlHESZDA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_kovSpz9r, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_PabYxCZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hrDWzKpe_sendMessage);
}

void Heavy_ChaffVerb::cSystem_hrDWzKpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_h3yqSZMw_sendMessage);
}

void Heavy_ChaffVerb::cVar_1mD8oCk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mmRYOpQj_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_i4dbjr9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_spqPlCOv_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_TDHf8Amr, m);
}

void Heavy_ChaffVerb::cBinop_h3yqSZMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_g9hHyq0m, m);
}

void Heavy_ChaffVerb::cMsg_mmRYOpQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_i4dbjr9X_sendMessage);
}

void Heavy_ChaffVerb::cBinop_spqPlCOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_5zTihDPy, m);
}

void Heavy_ChaffVerb::cMsg_jN9gxhTI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_50UXcZTL_sendMessage);
}

void Heavy_ChaffVerb::cSystem_50UXcZTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_VOnYMirm_sendMessage);
}

void Heavy_ChaffVerb::cVar_d88K8eWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fWC9TLtt_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSystem_gSIhklGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_16tiqgOF_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_vQAxcnNF, m);
}

void Heavy_ChaffVerb::cBinop_VOnYMirm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GKDcIbr0, m);
}

void Heavy_ChaffVerb::cMsg_fWC9TLtt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gSIhklGo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_16tiqgOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_wnp1tdI3, m);
}

void Heavy_ChaffVerb::cBinop_ZzqV0Wrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YrggNKTg, 0, m, &cVar_YrggNKTg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_z3q7wihp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FtG5ge5K_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8wsiVo4Q_sendMessage);
}

void Heavy_ChaffVerb::cCast_8wsiVo4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZzqV0Wrk, HV_BINOP_DIVIDE, 0, m, &cBinop_ZzqV0Wrk_sendMessage);
}

void Heavy_ChaffVerb::cCast_FtG5ge5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZzqV0Wrk, HV_BINOP_DIVIDE, 1, m, &cBinop_ZzqV0Wrk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_hW9n9UyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_VbWwaabz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PjcqGZLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 87.3365f, 0, m, &cBinop_rIIaJH8v_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VbWwaabz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZzqV0Wrk, HV_BINOP_DIVIDE, 0, m, &cBinop_ZzqV0Wrk_sendMessage);
}

void Heavy_ChaffVerb::cBinop_kgEd5FjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_PEhMOqG0, 0, m, &cPack_PEhMOqG0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ZOqCrqcW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.001f, 0, m, &cBinop_z3q7wihp_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_OeLRRMte, 0, m, &cPack_OeLRRMte_sendMessage);
}

void Heavy_ChaffVerb::cUnop_Qu6BhrSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hqOg6l6l, 0, m, &cIf_hqOg6l6l_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_kwJugb8M_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_m9HLIKZo_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SkOFFj4l_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JvHLgw2s_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_m9HLIKZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D9hyekGK_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_SkOFFj4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_drlxqODw_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cCast_JvHLgw2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kEA2gxFH_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_hE7ZfJhP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_IWvwelh8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_IWvwelh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_0jABJO2R_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_cwYgPxFR_sendMessage);
}

void Heavy_ChaffVerb::cVar_hA4fkERM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_gjz5q2LE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vUvCpcOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fqfW3nUH_sendMessage);
}

void Heavy_ChaffVerb::cSystem_fqfW3nUH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v1n9RbOe, HV_BINOP_DIVIDE, 1, m, &cBinop_v1n9RbOe_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0jABJO2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_RlwBxr5n_sendMessage);
}

void Heavy_ChaffVerb::cBinop_RlwBxr5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_70I1lGSq, m);
}

void Heavy_ChaffVerb::cMsg_LCO6Vpyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5ouTwwmN_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5ouTwwmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_hE7ZfJhP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_cwYgPxFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_UYJxN8m4, m);
}

void Heavy_ChaffVerb::cBinop_gjz5q2LE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_Y9LpSix2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Y9LpSix2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v1n9RbOe, HV_BINOP_DIVIDE, 0, m, &cBinop_v1n9RbOe_sendMessage);
}

void Heavy_ChaffVerb::cBinop_v1n9RbOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LCO6Vpyv_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_mNc7OmaJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7E64BD01: { // "seed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_j3y1it7M, 0, m, &cSlice_j3y1it7M_sendMessage);
      break;
    }
    default: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_1VycPsHK, 0, m, &cRandom_1VycPsHK_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_6tz4Csag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_yewPOf3t_sendMessage);
}

void Heavy_ChaffVerb::cUnop_yewPOf3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 50.0f, 0, m, &cBinop_WsLJXTAZ_sendMessage);
}

void Heavy_ChaffVerb::cRandom_1VycPsHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_6tz4Csag_sendMessage);
}

void Heavy_ChaffVerb::cSlice_j3y1it7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cRandom_onMessage(_c, &Context(_c)->cRandom_1VycPsHK, 1, m, &cRandom_1VycPsHK_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSwitchcase_hZZHMQyp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_iamErm6I_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_iamErm6I_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5Nr6ftid_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_C3TAoQXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_C3TAoQXZ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_C3TAoQXZ, 0, m, &cDelay_C3TAoQXZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eNNMsWrr, 0, m, &cVar_eNNMsWrr_sendMessage);
}

void Heavy_ChaffVerb::cCast_5Nr6ftid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iamErm6I_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_C3TAoQXZ, 0, m, &cDelay_C3TAoQXZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eNNMsWrr, 0, m, &cVar_eNNMsWrr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FDF7kgcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NGGZuGIF_sendMessage);
}

void Heavy_ChaffVerb::cSystem_NGGZuGIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_5PYXhRoO_sendMessage);
}

void Heavy_ChaffVerb::cVar_QuhCQpwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wdt8ql6g, HV_BINOP_MULTIPLY, 0, m, &cBinop_Wdt8ql6g_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iamErm6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_C3TAoQXZ, 0, m, &cDelay_C3TAoQXZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vCucB2G2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_C3TAoQXZ, 2, m, &cDelay_C3TAoQXZ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5PYXhRoO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wdt8ql6g, HV_BINOP_MULTIPLY, 1, m, &cBinop_Wdt8ql6g_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Wdt8ql6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_vCucB2G2_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_f5scY1oh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X8y8pulQ, HV_BINOP_SUBTRACT, 0, m, &cBinop_X8y8pulQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_A7Ttnv2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_tmlvm2ca_sendMessage);
}

void Heavy_ChaffVerb::cSystem_tmlvm2ca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_UdFuZ2oT_sendMessage);
}

void Heavy_ChaffVerb::cVar_ZfGG7kUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IVCTHa0K_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_7veAeliV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7veAeliV, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ppEuWDOd, 0, m, &cDelay_ppEuWDOd_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_lbMhGGh8, 0, m, &sTabread_lbMhGGh8_sendMessage);
}

void Heavy_ChaffVerb::cDelay_ppEuWDOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ppEuWDOd, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_lbMhGGh8, 0, m, &sTabread_lbMhGGh8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ppEuWDOd, 0, m, &cDelay_ppEuWDOd_sendMessage);
}

void Heavy_ChaffVerb::sTabread_lbMhGGh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_YxkxWfZT, HV_BINOP_SUBTRACT, 0, m, &cBinop_YxkxWfZT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_j8ZJgMdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xMRBQ0F0, HV_BINOP_MAX, 0, m, &cBinop_xMRBQ0F0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UdFuZ2oT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j8ZJgMdB, HV_BINOP_MULTIPLY, 0, m, &cBinop_j8ZJgMdB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_X8y8pulQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_falKzTu4_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_lbMhGGh8, 0, m, &sTabread_lbMhGGh8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sHtleF7k_sendMessage);
}

void Heavy_ChaffVerb::cSystem_FLFTLZvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YxkxWfZT, HV_BINOP_SUBTRACT, 1, m, &cBinop_YxkxWfZT_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ppEuWDOd, 2, m, &cDelay_ppEuWDOd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IVCTHa0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FLFTLZvw_sendMessage);
}

void Heavy_ChaffVerb::cMsg_falKzTu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7veAeliV, 0, m, &cDelay_7veAeliV_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ppEuWDOd, 0, m, &cDelay_ppEuWDOd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_7PoeOOYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_xMRBQ0F0, HV_BINOP_MAX, 1, m, &cBinop_xMRBQ0F0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xMRBQ0F0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X8y8pulQ, HV_BINOP_SUBTRACT, 1, m, &cBinop_X8y8pulQ_sendMessage);
}

void Heavy_ChaffVerb::cCast_sHtleF7k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7veAeliV, 0, m, &cDelay_7veAeliV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vq8Nevjs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7veAeliV, 2, m, &cDelay_7veAeliV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_YxkxWfZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vq8Nevjs_sendMessage);
}

void Heavy_ChaffVerb::cCast_77nigPNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZfGG7kUd, 0, m, &cVar_ZfGG7kUd_sendMessage);
  cMsg_A7Ttnv2X_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_f5scY1oh, 0, m, &cTabhead_f5scY1oh_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_2zXlWrsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UVeXvTfP, HV_BINOP_SUBTRACT, 0, m, &cBinop_UVeXvTfP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zjxJnl4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_cZYcE095_sendMessage);
}

void Heavy_ChaffVerb::cSystem_cZYcE095_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_G0xilt08_sendMessage);
}

void Heavy_ChaffVerb::cVar_Sw6GbnAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PSvwghLq_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_DXoi3xNF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DXoi3xNF, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QXGvgeGM, 0, m, &cDelay_QXGvgeGM_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_rgWwA9DW, 0, m, &sTabread_rgWwA9DW_sendMessage);
}

void Heavy_ChaffVerb::cDelay_QXGvgeGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QXGvgeGM, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_rgWwA9DW, 0, m, &sTabread_rgWwA9DW_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QXGvgeGM, 0, m, &cDelay_QXGvgeGM_sendMessage);
}

void Heavy_ChaffVerb::sTabread_rgWwA9DW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_RKFY2Or3, HV_BINOP_SUBTRACT, 0, m, &cBinop_RKFY2Or3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_XM62KSBn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7c1eLwF9, HV_BINOP_MAX, 0, m, &cBinop_7c1eLwF9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_G0xilt08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XM62KSBn, HV_BINOP_MULTIPLY, 0, m, &cBinop_XM62KSBn_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UVeXvTfP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5b8FMd0o_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_rgWwA9DW, 0, m, &sTabread_rgWwA9DW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_idT466zx_sendMessage);
}

void Heavy_ChaffVerb::cSystem_5HYef4S7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RKFY2Or3, HV_BINOP_SUBTRACT, 1, m, &cBinop_RKFY2Or3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QXGvgeGM, 2, m, &cDelay_QXGvgeGM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_PSvwghLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5HYef4S7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5b8FMd0o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_DXoi3xNF, 0, m, &cDelay_DXoi3xNF_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_QXGvgeGM, 0, m, &cDelay_QXGvgeGM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CBqWEhec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_7c1eLwF9, HV_BINOP_MAX, 1, m, &cBinop_7c1eLwF9_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7c1eLwF9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UVeXvTfP, HV_BINOP_SUBTRACT, 1, m, &cBinop_UVeXvTfP_sendMessage);
}

void Heavy_ChaffVerb::cCast_idT466zx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DXoi3xNF, 0, m, &cDelay_DXoi3xNF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_W7ZNk5qV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DXoi3xNF, 2, m, &cDelay_DXoi3xNF_sendMessage);
}

void Heavy_ChaffVerb::cBinop_RKFY2Or3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_W7ZNk5qV_sendMessage);
}

void Heavy_ChaffVerb::cCast_Vdijw31d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Sw6GbnAT, 0, m, &cVar_Sw6GbnAT_sendMessage);
  cMsg_zjxJnl4v_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_2zXlWrsb, 0, m, &cTabhead_2zXlWrsb_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_Rx211Gl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CikmU2x1, HV_BINOP_SUBTRACT, 0, m, &cBinop_CikmU2x1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xnYlNBKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_p996eKX8_sendMessage);
}

void Heavy_ChaffVerb::cSystem_p996eKX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_G6xYtOEN_sendMessage);
}

void Heavy_ChaffVerb::cVar_wnPFyn0B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CYakC6wp_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_xGdiGprP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xGdiGprP, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GPq6X1xj, 0, m, &cDelay_GPq6X1xj_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_3Ak4ouDU, 0, m, &sTabread_3Ak4ouDU_sendMessage);
}

void Heavy_ChaffVerb::cDelay_GPq6X1xj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GPq6X1xj, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_3Ak4ouDU, 0, m, &sTabread_3Ak4ouDU_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GPq6X1xj, 0, m, &cDelay_GPq6X1xj_sendMessage);
}

void Heavy_ChaffVerb::sTabread_3Ak4ouDU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_eE9xk2dd, HV_BINOP_SUBTRACT, 0, m, &cBinop_eE9xk2dd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_8JstMwXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0PYOrqZY, HV_BINOP_MAX, 0, m, &cBinop_0PYOrqZY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_G6xYtOEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8JstMwXw, HV_BINOP_MULTIPLY, 0, m, &cBinop_8JstMwXw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CikmU2x1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S4U6S2wN_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_3Ak4ouDU, 0, m, &sTabread_3Ak4ouDU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gVrtZDau_sendMessage);
}

void Heavy_ChaffVerb::cSystem_FJ9Gl3px_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eE9xk2dd, HV_BINOP_SUBTRACT, 1, m, &cBinop_eE9xk2dd_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GPq6X1xj, 2, m, &cDelay_GPq6X1xj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CYakC6wp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_FJ9Gl3px_sendMessage);
}

void Heavy_ChaffVerb::cMsg_S4U6S2wN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xGdiGprP, 0, m, &cDelay_xGdiGprP_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GPq6X1xj, 0, m, &cDelay_GPq6X1xj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Ds5ZulnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_0PYOrqZY, HV_BINOP_MAX, 1, m, &cBinop_0PYOrqZY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_0PYOrqZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CikmU2x1, HV_BINOP_SUBTRACT, 1, m, &cBinop_CikmU2x1_sendMessage);
}

void Heavy_ChaffVerb::cCast_gVrtZDau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xGdiGprP, 0, m, &cDelay_xGdiGprP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SLKi51Hy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xGdiGprP, 2, m, &cDelay_xGdiGprP_sendMessage);
}

void Heavy_ChaffVerb::cBinop_eE9xk2dd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_SLKi51Hy_sendMessage);
}

void Heavy_ChaffVerb::cCast_tZJcC2eM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wnPFyn0B, 0, m, &cVar_wnPFyn0B_sendMessage);
  cMsg_xnYlNBKh_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Rx211Gl0, 0, m, &cTabhead_Rx211Gl0_sendMessage);
}

void Heavy_ChaffVerb::cTabhead_xMW0s7PV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CJbQoirA, HV_BINOP_SUBTRACT, 0, m, &cBinop_CJbQoirA_sendMessage);
}

void Heavy_ChaffVerb::cMsg_w5nA9XG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZiWKV6i9_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ZiWKV6i9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_aXXh7TDd_sendMessage);
}

void Heavy_ChaffVerb::cVar_JiFE195Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_67NK65Nh_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_v1UtFv5S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_v1UtFv5S, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jt08iaCM, 0, m, &cDelay_jt08iaCM_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_1pZDNPqC, 0, m, &sTabread_1pZDNPqC_sendMessage);
}

void Heavy_ChaffVerb::cDelay_jt08iaCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jt08iaCM, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_1pZDNPqC, 0, m, &sTabread_1pZDNPqC_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jt08iaCM, 0, m, &cDelay_jt08iaCM_sendMessage);
}

void Heavy_ChaffVerb::sTabread_1pZDNPqC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_C9ZgeSuI, HV_BINOP_SUBTRACT, 0, m, &cBinop_C9ZgeSuI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_IVWZgiW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NOVskrzd, HV_BINOP_MAX, 0, m, &cBinop_NOVskrzd_sendMessage);
}

void Heavy_ChaffVerb::cBinop_aXXh7TDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IVWZgiW8, HV_BINOP_MULTIPLY, 0, m, &cBinop_IVWZgiW8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CJbQoirA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QMYj1bI6_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_1pZDNPqC, 0, m, &sTabread_1pZDNPqC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QORjxBgk_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Er6CD2m0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C9ZgeSuI, HV_BINOP_SUBTRACT, 1, m, &cBinop_C9ZgeSuI_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jt08iaCM, 2, m, &cDelay_jt08iaCM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_67NK65Nh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Er6CD2m0_sendMessage);
}

void Heavy_ChaffVerb::cMsg_QMYj1bI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_v1UtFv5S, 0, m, &cDelay_v1UtFv5S_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_jt08iaCM, 0, m, &cDelay_jt08iaCM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Q3uOWQhs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_NOVskrzd, HV_BINOP_MAX, 1, m, &cBinop_NOVskrzd_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NOVskrzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CJbQoirA, HV_BINOP_SUBTRACT, 1, m, &cBinop_CJbQoirA_sendMessage);
}

void Heavy_ChaffVerb::cCast_QORjxBgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_v1UtFv5S, 0, m, &cDelay_v1UtFv5S_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QpfRXW03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_v1UtFv5S, 2, m, &cDelay_v1UtFv5S_sendMessage);
}

void Heavy_ChaffVerb::cBinop_C9ZgeSuI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_QpfRXW03_sendMessage);
}

void Heavy_ChaffVerb::cCast_Fa21SR58_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JiFE195Y, 0, m, &cVar_JiFE195Y_sendMessage);
  cMsg_w5nA9XG4_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_xMW0s7PV, 0, m, &cTabhead_xMW0s7PV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Mv4xBO6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_aYoS0I4Y_sendMessage);
}

void Heavy_ChaffVerb::cSystem_aYoS0I4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_SDq1LMjP_sendMessage);
}

void Heavy_ChaffVerb::cDelay_nQmcczef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nQmcczef, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_CF6yMHOm, 0, m, &cDelay_CF6yMHOm_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nQmcczef, 0, m, &cDelay_nQmcczef_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_GZPbtpSe, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_CF6yMHOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CF6yMHOm, m);
  cMsg_OaTZ5VwQ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_UhTLInla_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_4LGpty51_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_VNictWua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PZE44VL1_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_7P3o9gMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sj6fAwRS_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_nQmcczef, 2, m, &cDelay_nQmcczef_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gxGQWsjm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_PZE44VL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_7P3o9gMy, 0, m, &hTable_7P3o9gMy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SDq1LMjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 58.6435f, 0, m, &cBinop_VNictWua_sendMessage);
}

void Heavy_ChaffVerb::cMsg_OaTZ5VwQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_7P3o9gMy, 0, m, &hTable_7P3o9gMy_sendMessage);
}

void Heavy_ChaffVerb::cCast_gxGQWsjm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nQmcczef, 0, m, &cDelay_nQmcczef_sendMessage);
}

void Heavy_ChaffVerb::cMsg_sj6fAwRS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_CF6yMHOm, 2, m, &cDelay_CF6yMHOm_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4LGpty51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_GZPbtpSe, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_VkivXlYp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_qP30LYTJ_sendMessage);
}

void Heavy_ChaffVerb::cSystem_qP30LYTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_SlNQPlFE_sendMessage);
}

void Heavy_ChaffVerb::cDelay_x5gKqtX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_x5gKqtX9, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_xXKLG6nr, 0, m, &cDelay_xXKLG6nr_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_x5gKqtX9, 0, m, &cDelay_x5gKqtX9_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_oL7HH7At, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_xXKLG6nr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xXKLG6nr, m);
  cMsg_ZLl7AdII_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_nB6o53dS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_WeQ4Lxwb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_DByGilSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L42fiWwo_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_gs61gmfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pyorebGn_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_x5gKqtX9, 2, m, &cDelay_x5gKqtX9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Jb26kOPy_sendMessage);
}

void Heavy_ChaffVerb::cMsg_L42fiWwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_gs61gmfv, 0, m, &hTable_gs61gmfv_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SlNQPlFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 69.4325f, 0, m, &cBinop_DByGilSJ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ZLl7AdII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_gs61gmfv, 0, m, &hTable_gs61gmfv_sendMessage);
}

void Heavy_ChaffVerb::cCast_Jb26kOPy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_x5gKqtX9, 0, m, &cDelay_x5gKqtX9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pyorebGn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_xXKLG6nr, 2, m, &cDelay_xXKLG6nr_sendMessage);
}

void Heavy_ChaffVerb::cMsg_WeQ4Lxwb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_oL7HH7At, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_jSscqJZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_AC5SrtDu_sendMessage);
}

void Heavy_ChaffVerb::cSystem_AC5SrtDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ag1QM7qI_sendMessage);
}

void Heavy_ChaffVerb::cDelay_1gsC74wu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1gsC74wu, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_gqIkb1WM, 0, m, &cDelay_gqIkb1WM_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1gsC74wu, 0, m, &cDelay_1gsC74wu_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_fmchOf5p, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_gqIkb1WM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gqIkb1WM, m);
  cMsg_wrNS3yvH_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_OsGtzoR1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_61oWFkDz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_Jcgw7ocj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3TbqKRq6_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_ISG38vW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zgCKkVNu_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1gsC74wu, 2, m, &cDelay_1gsC74wu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RsNoP64V_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3TbqKRq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ISG38vW3, 0, m, &hTable_ISG38vW3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ag1QM7qI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 74.5234f, 0, m, &cBinop_Jcgw7ocj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wrNS3yvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ISG38vW3, 0, m, &hTable_ISG38vW3_sendMessage);
}

void Heavy_ChaffVerb::cCast_RsNoP64V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1gsC74wu, 0, m, &cDelay_1gsC74wu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zgCKkVNu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_gqIkb1WM, 2, m, &cDelay_gqIkb1WM_sendMessage);
}

void Heavy_ChaffVerb::cMsg_61oWFkDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_fmchOf5p, 1, m, NULL);
}

void Heavy_ChaffVerb::cMsg_wyFh5gnp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LXojPdK4_sendMessage);
}

void Heavy_ChaffVerb::cSystem_LXojPdK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_QubCm8Ky_sendMessage);
}

void Heavy_ChaffVerb::cDelay_N4lkxbed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_N4lkxbed, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_KQecCqRY, 0, m, &cDelay_KQecCqRY_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_N4lkxbed, 0, m, &cDelay_N4lkxbed_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_rxM77lpU, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_KQecCqRY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KQecCqRY, m);
  cMsg_X5qxt669_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_5bhuNfYh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_hsknai8B_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_ygwjhYho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GM1EEFMB_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_tVWrUQip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IdOdK6nN_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_N4lkxbed, 2, m, &cDelay_N4lkxbed_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ERTKu2ed_sendMessage);
}

void Heavy_ChaffVerb::cMsg_GM1EEFMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_tVWrUQip, 0, m, &hTable_tVWrUQip_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QubCm8Ky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 86.1244f, 0, m, &cBinop_ygwjhYho_sendMessage);
}

void Heavy_ChaffVerb::cMsg_X5qxt669_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_tVWrUQip, 0, m, &hTable_tVWrUQip_sendMessage);
}

void Heavy_ChaffVerb::cCast_ERTKu2ed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_N4lkxbed, 0, m, &cDelay_N4lkxbed_sendMessage);
}

void Heavy_ChaffVerb::cMsg_IdOdK6nN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_KQecCqRY, 2, m, &cDelay_KQecCqRY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_hsknai8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_rxM77lpU, 1, m, NULL);
}

void Heavy_ChaffVerb::cPack_ysisArw1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_C3gtSON1, 0, m, NULL);
}

void Heavy_ChaffVerb::cPack_IMfhzYHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_X5KtKCoM, 0, m, NULL);
}

void Heavy_ChaffVerb::cBinop_7Bgzmzco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_n5EYSupL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_n5EYSupL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 200.0f, 0, m, &cBinop_QqMx5MH8_sendMessage);
}

void Heavy_ChaffVerb::cVar_2FIEZts5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UhTa0DbQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_UhTa0DbQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_3Kuvqjub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BqYBjMsa_sendMessage);
}

void Heavy_ChaffVerb::cSystem_BqYBjMsa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PaxlrcFD_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_UhTa0DbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_a3uEsaFh_sendMessage);
}

void Heavy_ChaffVerb::cBinop_7MFrD751_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UhTa0DbQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_UhTa0DbQ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_PaxlrcFD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7MFrD751_sendMessage);
}

void Heavy_ChaffVerb::cBinop_a3uEsaFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_4Oy6z3b7_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4Oy6z3b7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_TjUt8cfW_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_0uaubYgj, m);
}

void Heavy_ChaffVerb::cBinop_TjUt8cfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_7qWi6hNp, m);
}

void Heavy_ChaffVerb::cVar_Hnu0ImOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.125f, 0, m, &cBinop_48NfRWTZ_sendMessage);
}

void Heavy_ChaffVerb::cVar_ZyF3XWg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_7Bgzmzco_sendMessage);
}

void Heavy_ChaffVerb::cVar_rZczA09m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN_EQL, 1.0f, 0, m, &cBinop_0oPYiTGS_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_sZVILnq5, 0, m, &cIf_sZVILnq5_sendMessage);
}

void Heavy_ChaffVerb::cVar_D0IlWBbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_eOKuyQRq_sendMessage);
}

void Heavy_ChaffVerb::cIf_sZVILnq5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_k5sMsTmL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_2KsF02Dp, 0, m, &cVar_2KsF02Dp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_0oPYiTGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sZVILnq5, 1, m, &cIf_sZVILnq5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_eOKuyQRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_mCtb5K1s_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mCtb5K1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_k39vTacD, 0, m, &cVar_k39vTacD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Alf0coaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_vIPjtkoa_sendMessage);
}

void Heavy_ChaffVerb::cSystem_vIPjtkoa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_M0pZcvnd_sendMessage);
}

void Heavy_ChaffVerb::cDelay_REx4CoTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_REx4CoTP, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NzN48K05, 0, m, &cDelay_NzN48K05_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_REx4CoTP, 0, m, &cDelay_REx4CoTP_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_42ludZgk, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_NzN48K05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NzN48K05, m);
  cMsg_6WodPdwz_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_gYiktADP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_83qGeIKB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_PvYwtS1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oluHNGsk_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_r2cmE7It_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4jsVpnoN_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_REx4CoTP, 2, m, &cDelay_REx4CoTP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LWAeWTGK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_oluHNGsk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_r2cmE7It, 0, m, &hTable_r2cmE7It_sendMessage);
}

void Heavy_ChaffVerb::cBinop_M0pZcvnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 43.5337f, 0, m, &cBinop_PvYwtS1q_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6WodPdwz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_r2cmE7It, 0, m, &hTable_r2cmE7It_sendMessage);
}

void Heavy_ChaffVerb::cCast_LWAeWTGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_REx4CoTP, 0, m, &cDelay_REx4CoTP_sendMessage);
}

void Heavy_ChaffVerb::cMsg_4jsVpnoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_NzN48K05, 2, m, &cDelay_NzN48K05_sendMessage);
}

void Heavy_ChaffVerb::cMsg_83qGeIKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_42ludZgk, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_SUKWcMMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MWqPR4Jp, HV_BINOP_SUBTRACT, 0, m, &cBinop_MWqPR4Jp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_v1qa1HXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fLhq5byw_sendMessage);
}

void Heavy_ChaffVerb::cSystem_fLhq5byw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_oVHK2658_sendMessage);
}

void Heavy_ChaffVerb::cVar_f0Fq9lAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xQboDXII_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_BYxoKq50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BYxoKq50, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_z75OKMqg, 0, m, &cDelay_z75OKMqg_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_G1SDi5ZH, 0, m, &sTabread_G1SDi5ZH_sendMessage);
}

void Heavy_ChaffVerb::cDelay_z75OKMqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_z75OKMqg, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_G1SDi5ZH, 0, m, &sTabread_G1SDi5ZH_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_z75OKMqg, 0, m, &cDelay_z75OKMqg_sendMessage);
}

void Heavy_ChaffVerb::sTabread_G1SDi5ZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_c2h3kxVM, HV_BINOP_SUBTRACT, 0, m, &cBinop_c2h3kxVM_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_5vuMbhgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qRrjtBu3, HV_BINOP_MAX, 0, m, &cBinop_qRrjtBu3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_oVHK2658_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5vuMbhgD, HV_BINOP_MULTIPLY, 0, m, &cBinop_5vuMbhgD_sendMessage);
}

void Heavy_ChaffVerb::cBinop_MWqPR4Jp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vxJhGkh6_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_G1SDi5ZH, 0, m, &sTabread_G1SDi5ZH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7fn3Uuk0_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ylIDBCy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c2h3kxVM, HV_BINOP_SUBTRACT, 1, m, &cBinop_c2h3kxVM_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_z75OKMqg, 2, m, &cDelay_z75OKMqg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_xQboDXII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ylIDBCy9_sendMessage);
}

void Heavy_ChaffVerb::cMsg_vxJhGkh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BYxoKq50, 0, m, &cDelay_BYxoKq50_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_z75OKMqg, 0, m, &cDelay_z75OKMqg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_e21ESNrm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_qRrjtBu3, HV_BINOP_MAX, 1, m, &cBinop_qRrjtBu3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qRrjtBu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MWqPR4Jp, HV_BINOP_SUBTRACT, 1, m, &cBinop_MWqPR4Jp_sendMessage);
}

void Heavy_ChaffVerb::cCast_7fn3Uuk0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BYxoKq50, 0, m, &cDelay_BYxoKq50_sendMessage);
}

void Heavy_ChaffVerb::cBinop_VyPkTbxz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BYxoKq50, 2, m, &cDelay_BYxoKq50_sendMessage);
}

void Heavy_ChaffVerb::cBinop_c2h3kxVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_VyPkTbxz_sendMessage);
}

void Heavy_ChaffVerb::cCast_eHSki6UL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f0Fq9lAy, 0, m, &cVar_f0Fq9lAy_sendMessage);
  cMsg_v1qa1HXn_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_SUKWcMMa, 0, m, &cTabhead_SUKWcMMa_sendMessage);
}

void Heavy_ChaffVerb::cMsg_CnVCIINV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JBo36tML_sendMessage);
}

void Heavy_ChaffVerb::cSystem_JBo36tML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_E1BdOahe_sendMessage);
}

void Heavy_ChaffVerb::cDelay_SZH4f8vZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SZH4f8vZ, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_15vycgP4, 0, m, &cDelay_15vycgP4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SZH4f8vZ, 0, m, &cDelay_SZH4f8vZ_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_PQoVLLNo, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_15vycgP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_15vycgP4, m);
  cMsg_UBGnNBmq_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_ysmKgXQS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_mU99j3Sw_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_7EW0VPcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HdCUeHrF_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_URpUJA48_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dflkirOc_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_SZH4f8vZ, 2, m, &cDelay_SZH4f8vZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K1EPPJev_sendMessage);
}

void Heavy_ChaffVerb::cMsg_HdCUeHrF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_URpUJA48, 0, m, &hTable_URpUJA48_sendMessage);
}

void Heavy_ChaffVerb::cBinop_E1BdOahe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 25.796f, 0, m, &cBinop_7EW0VPcG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UBGnNBmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_URpUJA48, 0, m, &hTable_URpUJA48_sendMessage);
}

void Heavy_ChaffVerb::cCast_K1EPPJev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SZH4f8vZ, 0, m, &cDelay_SZH4f8vZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dflkirOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_15vycgP4, 2, m, &cDelay_15vycgP4_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mU99j3Sw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_PQoVLLNo, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_TDE7z6fi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pX8CSwhn, HV_BINOP_SUBTRACT, 0, m, &cBinop_pX8CSwhn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_rqU2zSqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_bg0uxXNH_sendMessage);
}

void Heavy_ChaffVerb::cSystem_bg0uxXNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_9IAgwH0w_sendMessage);
}

void Heavy_ChaffVerb::cVar_u1eOx5yP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X9Yxjf5q_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_MRjbLZZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MRjbLZZT, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_M81ncLR1, 0, m, &cDelay_M81ncLR1_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_D6Yszqpj, 0, m, &sTabread_D6Yszqpj_sendMessage);
}

void Heavy_ChaffVerb::cDelay_M81ncLR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_M81ncLR1, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_D6Yszqpj, 0, m, &sTabread_D6Yszqpj_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_M81ncLR1, 0, m, &cDelay_M81ncLR1_sendMessage);
}

void Heavy_ChaffVerb::sTabread_D6Yszqpj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_l1G10hPH, HV_BINOP_SUBTRACT, 0, m, &cBinop_l1G10hPH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_VLODo76A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wCK7l7hX, HV_BINOP_MAX, 0, m, &cBinop_wCK7l7hX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_9IAgwH0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VLODo76A, HV_BINOP_MULTIPLY, 0, m, &cBinop_VLODo76A_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pX8CSwhn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FJNm3kCy_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_D6Yszqpj, 0, m, &sTabread_D6Yszqpj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tc47mZk5_sendMessage);
}

void Heavy_ChaffVerb::cSystem_NI79Vzc7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_l1G10hPH, HV_BINOP_SUBTRACT, 1, m, &cBinop_l1G10hPH_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_M81ncLR1, 2, m, &cDelay_M81ncLR1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_X9Yxjf5q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_NI79Vzc7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FJNm3kCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MRjbLZZT, 0, m, &cDelay_MRjbLZZT_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_M81ncLR1, 0, m, &cDelay_M81ncLR1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_OUcxLTHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_wCK7l7hX, HV_BINOP_MAX, 1, m, &cBinop_wCK7l7hX_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wCK7l7hX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pX8CSwhn, HV_BINOP_SUBTRACT, 1, m, &cBinop_pX8CSwhn_sendMessage);
}

void Heavy_ChaffVerb::cCast_tc47mZk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MRjbLZZT, 0, m, &cDelay_MRjbLZZT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_O6A1elOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MRjbLZZT, 2, m, &cDelay_MRjbLZZT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_l1G10hPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_O6A1elOr_sendMessage);
}

void Heavy_ChaffVerb::cCast_e7zMxX7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_u1eOx5yP, 0, m, &cVar_u1eOx5yP_sendMessage);
  cMsg_rqU2zSqx_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_TDE7z6fi, 0, m, &cTabhead_TDE7z6fi_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Leyv0cfT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_l0jKFGf4_sendMessage);
}

void Heavy_ChaffVerb::cSystem_l0jKFGf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_3pTvB4U4_sendMessage);
}

void Heavy_ChaffVerb::cDelay_M7cDhrrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_M7cDhrrN, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZHFh339D, 0, m, &cDelay_ZHFh339D_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_M7cDhrrN, 0, m, &cDelay_M7cDhrrN_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_lu6EhYt8, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_ZHFh339D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZHFh339D, m);
  cMsg_w78KtTXu_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_rUPllykS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_TvflXALl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_8Zh7iMWx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wX7vDkU1_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_TkDvhtvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ww6pC9dY_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_M7cDhrrN, 2, m, &cDelay_M7cDhrrN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uU8pkajZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_wX7vDkU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_TkDvhtvi, 0, m, &hTable_TkDvhtvi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_3pTvB4U4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 19.392f, 0, m, &cBinop_8Zh7iMWx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_w78KtTXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_TkDvhtvi, 0, m, &hTable_TkDvhtvi_sendMessage);
}

void Heavy_ChaffVerb::cCast_uU8pkajZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_M7cDhrrN, 0, m, &cDelay_M7cDhrrN_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Ww6pC9dY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZHFh339D, 2, m, &cDelay_ZHFh339D_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TvflXALl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_lu6EhYt8, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_MnyGpRp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DAguFkuB, HV_BINOP_SUBTRACT, 0, m, &cBinop_DAguFkuB_sendMessage);
}

void Heavy_ChaffVerb::cMsg_AMa1zYcx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Iy5j61Lv_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Iy5j61Lv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_xfeu4pQ8_sendMessage);
}

void Heavy_ChaffVerb::cVar_a0vya4bC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_60FJoj5E_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_JhObY49w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JhObY49w, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iBbI1zou, 0, m, &cDelay_iBbI1zou_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_AKzQNmPk, 0, m, &sTabread_AKzQNmPk_sendMessage);
}

void Heavy_ChaffVerb::cDelay_iBbI1zou_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_iBbI1zou, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_AKzQNmPk, 0, m, &sTabread_AKzQNmPk_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iBbI1zou, 0, m, &cDelay_iBbI1zou_sendMessage);
}

void Heavy_ChaffVerb::sTabread_AKzQNmPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_pL8yMn1I, HV_BINOP_SUBTRACT, 0, m, &cBinop_pL8yMn1I_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_lP2J3Xln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8zxIf878, HV_BINOP_MAX, 0, m, &cBinop_8zxIf878_sendMessage);
}

void Heavy_ChaffVerb::cBinop_xfeu4pQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lP2J3Xln, HV_BINOP_MULTIPLY, 0, m, &cBinop_lP2J3Xln_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DAguFkuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SPjS0shm_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_AKzQNmPk, 0, m, &sTabread_AKzQNmPk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CvPRc3Ho_sendMessage);
}

void Heavy_ChaffVerb::cSystem_DWiBkQzu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pL8yMn1I, HV_BINOP_SUBTRACT, 1, m, &cBinop_pL8yMn1I_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iBbI1zou, 2, m, &cDelay_iBbI1zou_sendMessage);
}

void Heavy_ChaffVerb::cMsg_60FJoj5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DWiBkQzu_sendMessage);
}

void Heavy_ChaffVerb::cMsg_SPjS0shm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JhObY49w, 0, m, &cDelay_JhObY49w_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_iBbI1zou, 0, m, &cDelay_iBbI1zou_sendMessage);
}

void Heavy_ChaffVerb::cMsg_iLQpyHzm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_8zxIf878, HV_BINOP_MAX, 1, m, &cBinop_8zxIf878_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8zxIf878_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DAguFkuB, HV_BINOP_SUBTRACT, 1, m, &cBinop_DAguFkuB_sendMessage);
}

void Heavy_ChaffVerb::cCast_CvPRc3Ho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JhObY49w, 0, m, &cDelay_JhObY49w_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qOVVG4wy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JhObY49w, 2, m, &cDelay_JhObY49w_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pL8yMn1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_qOVVG4wy_sendMessage);
}

void Heavy_ChaffVerb::cCast_gCAy8555_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_a0vya4bC, 0, m, &cVar_a0vya4bC_sendMessage);
  cMsg_AMa1zYcx_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_MnyGpRp5, 0, m, &cTabhead_MnyGpRp5_sendMessage);
}

void Heavy_ChaffVerb::cMsg_8ex0AYhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mFPYTkpK_sendMessage);
}

void Heavy_ChaffVerb::cSystem_mFPYTkpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_faJcnOfn_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Inzg5KFv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Inzg5KFv, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VzKYvr8f, 0, m, &cDelay_VzKYvr8f_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Inzg5KFv, 0, m, &cDelay_Inzg5KFv_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ELDdyV01, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_VzKYvr8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VzKYvr8f, m);
  cMsg_Olp469QW_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_Pn1L4I5f_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_mCtDQNYV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_RgM3gUIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dLq7WqFW_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_0ajfZMEY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VsJf8X86_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Inzg5KFv, 2, m, &cDelay_Inzg5KFv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ojMx6C3x_sendMessage);
}

void Heavy_ChaffVerb::cMsg_dLq7WqFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_0ajfZMEY, 0, m, &hTable_0ajfZMEY_sendMessage);
}

void Heavy_ChaffVerb::cBinop_faJcnOfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 16.364f, 0, m, &cBinop_RgM3gUIb_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Olp469QW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_0ajfZMEY, 0, m, &hTable_0ajfZMEY_sendMessage);
}

void Heavy_ChaffVerb::cCast_ojMx6C3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Inzg5KFv, 0, m, &cDelay_Inzg5KFv_sendMessage);
}

void Heavy_ChaffVerb::cMsg_VsJf8X86_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_VzKYvr8f, 2, m, &cDelay_VzKYvr8f_sendMessage);
}

void Heavy_ChaffVerb::cMsg_mCtDQNYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_ELDdyV01, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_Ni9gslk7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zJeU2Lmk, HV_BINOP_SUBTRACT, 0, m, &cBinop_zJeU2Lmk_sendMessage);
}

void Heavy_ChaffVerb::cMsg_XU3A0b54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SEa406mH_sendMessage);
}

void Heavy_ChaffVerb::cSystem_SEa406mH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_dlVXgQl7_sendMessage);
}

void Heavy_ChaffVerb::cVar_CIS60FzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fwH12Ljo_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_CUvzfoGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CUvzfoGB, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_igQF6fRj, 0, m, &cDelay_igQF6fRj_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_lRbL4hdp, 0, m, &sTabread_lRbL4hdp_sendMessage);
}

void Heavy_ChaffVerb::cDelay_igQF6fRj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_igQF6fRj, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_lRbL4hdp, 0, m, &sTabread_lRbL4hdp_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_igQF6fRj, 0, m, &cDelay_igQF6fRj_sendMessage);
}

void Heavy_ChaffVerb::sTabread_lRbL4hdp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_yr7jGdyo, HV_BINOP_SUBTRACT, 0, m, &cBinop_yr7jGdyo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_QknBrir8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8cOKDLtW, HV_BINOP_MAX, 0, m, &cBinop_8cOKDLtW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_dlVXgQl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QknBrir8, HV_BINOP_MULTIPLY, 0, m, &cBinop_QknBrir8_sendMessage);
}

void Heavy_ChaffVerb::cBinop_zJeU2Lmk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Kual2FRi_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_lRbL4hdp, 0, m, &sTabread_lRbL4hdp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gSt5gQA7_sendMessage);
}

void Heavy_ChaffVerb::cSystem_0xVqCYaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yr7jGdyo, HV_BINOP_SUBTRACT, 1, m, &cBinop_yr7jGdyo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_igQF6fRj, 2, m, &cDelay_igQF6fRj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_fwH12Ljo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_0xVqCYaZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Kual2FRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CUvzfoGB, 0, m, &cDelay_CUvzfoGB_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_igQF6fRj, 0, m, &cDelay_igQF6fRj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_97bDg6Jg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_8cOKDLtW, HV_BINOP_MAX, 1, m, &cBinop_8cOKDLtW_sendMessage);
}

void Heavy_ChaffVerb::cBinop_8cOKDLtW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zJeU2Lmk, HV_BINOP_SUBTRACT, 1, m, &cBinop_zJeU2Lmk_sendMessage);
}

void Heavy_ChaffVerb::cCast_gSt5gQA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CUvzfoGB, 0, m, &cDelay_CUvzfoGB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_Vu6lCv1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CUvzfoGB, 2, m, &cDelay_CUvzfoGB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_yr7jGdyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Vu6lCv1u_sendMessage);
}

void Heavy_ChaffVerb::cCast_VA7RLFK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CIS60FzH, 0, m, &cVar_CIS60FzH_sendMessage);
  cMsg_XU3A0b54_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Ni9gslk7, 0, m, &cTabhead_Ni9gslk7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zQBoeYIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QoxFiR1U_sendMessage);
}

void Heavy_ChaffVerb::cSystem_QoxFiR1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_p9JzKQ5M_sendMessage);
}

void Heavy_ChaffVerb::cDelay_qhv4rS7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qhv4rS7t, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_5zfXzVyg, 0, m, &cDelay_5zfXzVyg_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qhv4rS7t, 0, m, &cDelay_qhv4rS7t_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_03GQTMG4, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_5zfXzVyg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5zfXzVyg, m);
  cMsg_aEOU1QhQ_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_cQ2VYcvS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_ls4zDvux_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_wjbB7M3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6cujA47n_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_FrHixOBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pfNtXL2w_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qhv4rS7t, 2, m, &cDelay_qhv4rS7t_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nzO8HXHF_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6cujA47n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_FrHixOBB, 0, m, &hTable_FrHixOBB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_p9JzKQ5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 4.2546f, 0, m, &cBinop_wjbB7M3A_sendMessage);
}

void Heavy_ChaffVerb::cMsg_aEOU1QhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_FrHixOBB, 0, m, &hTable_FrHixOBB_sendMessage);
}

void Heavy_ChaffVerb::cCast_nzO8HXHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qhv4rS7t, 0, m, &cDelay_qhv4rS7t_sendMessage);
}

void Heavy_ChaffVerb::cMsg_pfNtXL2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_5zfXzVyg, 2, m, &cDelay_5zfXzVyg_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ls4zDvux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_03GQTMG4, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_6kLrEwM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AsTRbLJH, HV_BINOP_SUBTRACT, 0, m, &cBinop_AsTRbLJH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_PN2OqB6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zdns2dhv_sendMessage);
}

void Heavy_ChaffVerb::cSystem_zdns2dhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_E4wNv3dh_sendMessage);
}

void Heavy_ChaffVerb::cVar_hrAX5gyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kdKv8S5k_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_4WRJV5qe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4WRJV5qe, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qiGANPvY, 0, m, &cDelay_qiGANPvY_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_dU5YsroQ, 0, m, &sTabread_dU5YsroQ_sendMessage);
}

void Heavy_ChaffVerb::cDelay_qiGANPvY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qiGANPvY, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_dU5YsroQ, 0, m, &sTabread_dU5YsroQ_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qiGANPvY, 0, m, &cDelay_qiGANPvY_sendMessage);
}

void Heavy_ChaffVerb::sTabread_dU5YsroQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_6ScYRVsm, HV_BINOP_SUBTRACT, 0, m, &cBinop_6ScYRVsm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_Q1V4ts1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D0pkayHU, HV_BINOP_MAX, 0, m, &cBinop_D0pkayHU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_E4wNv3dh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Q1V4ts1Z, HV_BINOP_MULTIPLY, 0, m, &cBinop_Q1V4ts1Z_sendMessage);
}

void Heavy_ChaffVerb::cBinop_AsTRbLJH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ri2MGkyo_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_dU5YsroQ, 0, m, &sTabread_dU5YsroQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RdizJPX4_sendMessage);
}

void Heavy_ChaffVerb::cSystem_U7iMVUDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6ScYRVsm, HV_BINOP_SUBTRACT, 1, m, &cBinop_6ScYRVsm_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qiGANPvY, 2, m, &cDelay_qiGANPvY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kdKv8S5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_U7iMVUDZ_sendMessage);
}

void Heavy_ChaffVerb::cMsg_ri2MGkyo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4WRJV5qe, 0, m, &cDelay_4WRJV5qe_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qiGANPvY, 0, m, &cDelay_qiGANPvY_sendMessage);
}

void Heavy_ChaffVerb::cMsg_oddK0mys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_D0pkayHU, HV_BINOP_MAX, 1, m, &cBinop_D0pkayHU_sendMessage);
}

void Heavy_ChaffVerb::cBinop_D0pkayHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AsTRbLJH, HV_BINOP_SUBTRACT, 1, m, &cBinop_AsTRbLJH_sendMessage);
}

void Heavy_ChaffVerb::cCast_RdizJPX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4WRJV5qe, 0, m, &cDelay_4WRJV5qe_sendMessage);
}

void Heavy_ChaffVerb::cBinop_5q4fstTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4WRJV5qe, 2, m, &cDelay_4WRJV5qe_sendMessage);
}

void Heavy_ChaffVerb::cBinop_6ScYRVsm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_5q4fstTv_sendMessage);
}

void Heavy_ChaffVerb::cCast_MSMlS1ZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hrAX5gyS, 0, m, &cVar_hrAX5gyS_sendMessage);
  cMsg_PN2OqB6C_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_6kLrEwM8, 0, m, &cTabhead_6kLrEwM8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_uQtxBbMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UAeYv72F_sendMessage);
}

void Heavy_ChaffVerb::cSystem_UAeYv72F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_H5JjMAEB_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Sl7JcsbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Sl7JcsbL, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_BdzT4Pzp, 0, m, &cDelay_BdzT4Pzp_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Sl7JcsbL, 0, m, &cDelay_Sl7JcsbL_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_orbJMBl7, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_BdzT4Pzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BdzT4Pzp, m);
  cMsg_FoCU1CuS_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_B5tiwLw9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_R3IMqFvx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_sRaf3js8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_osZJzicY_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_ZO1cJ2EM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5jUj0xnp_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Sl7JcsbL, 2, m, &cDelay_Sl7JcsbL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X14qS9Wx_sendMessage);
}

void Heavy_ChaffVerb::cMsg_osZJzicY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_ZO1cJ2EM, 0, m, &hTable_ZO1cJ2EM_sendMessage);
}

void Heavy_ChaffVerb::cBinop_H5JjMAEB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 7.645f, 0, m, &cBinop_sRaf3js8_sendMessage);
}

void Heavy_ChaffVerb::cMsg_FoCU1CuS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_ZO1cJ2EM, 0, m, &hTable_ZO1cJ2EM_sendMessage);
}

void Heavy_ChaffVerb::cCast_X14qS9Wx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Sl7JcsbL, 0, m, &cDelay_Sl7JcsbL_sendMessage);
}

void Heavy_ChaffVerb::cMsg_5jUj0xnp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_BdzT4Pzp, 2, m, &cDelay_BdzT4Pzp_sendMessage);
}

void Heavy_ChaffVerb::cMsg_R3IMqFvx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_orbJMBl7, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_FBCmFB60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2QkhpdKV, HV_BINOP_SUBTRACT, 0, m, &cBinop_2QkhpdKV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Q6TQsLI1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KWAODDhB_sendMessage);
}

void Heavy_ChaffVerb::cSystem_KWAODDhB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_PRvAPGQx_sendMessage);
}

void Heavy_ChaffVerb::cVar_0QKLlUiN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kZCLbnen_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_RAX58SO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RAX58SO3, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IlowjLH7, 0, m, &cDelay_IlowjLH7_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_2MvsNWAi, 0, m, &sTabread_2MvsNWAi_sendMessage);
}

void Heavy_ChaffVerb::cDelay_IlowjLH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IlowjLH7, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_2MvsNWAi, 0, m, &sTabread_2MvsNWAi_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IlowjLH7, 0, m, &cDelay_IlowjLH7_sendMessage);
}

void Heavy_ChaffVerb::sTabread_2MvsNWAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_c1tV8sSn, HV_BINOP_SUBTRACT, 0, m, &cBinop_c1tV8sSn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_zUHCVro6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nWWXZpXL, HV_BINOP_MAX, 0, m, &cBinop_nWWXZpXL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_PRvAPGQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zUHCVro6, HV_BINOP_MULTIPLY, 0, m, &cBinop_zUHCVro6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2QkhpdKV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jrZ6nZrB_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_2MvsNWAi, 0, m, &sTabread_2MvsNWAi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SJocBX9R_sendMessage);
}

void Heavy_ChaffVerb::cSystem_gcc0iHoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c1tV8sSn, HV_BINOP_SUBTRACT, 1, m, &cBinop_c1tV8sSn_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IlowjLH7, 2, m, &cDelay_IlowjLH7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kZCLbnen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gcc0iHoS_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jrZ6nZrB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RAX58SO3, 0, m, &cDelay_RAX58SO3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_IlowjLH7, 0, m, &cDelay_IlowjLH7_sendMessage);
}

void Heavy_ChaffVerb::cMsg_B365BTga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_nWWXZpXL, HV_BINOP_MAX, 1, m, &cBinop_nWWXZpXL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nWWXZpXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2QkhpdKV, HV_BINOP_SUBTRACT, 1, m, &cBinop_2QkhpdKV_sendMessage);
}

void Heavy_ChaffVerb::cCast_SJocBX9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RAX58SO3, 0, m, &cDelay_RAX58SO3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_2SvDVIOO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RAX58SO3, 2, m, &cDelay_RAX58SO3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_c1tV8sSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_2SvDVIOO_sendMessage);
}

void Heavy_ChaffVerb::cCast_Fp5AMqbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0QKLlUiN, 0, m, &cVar_0QKLlUiN_sendMessage);
  cMsg_Q6TQsLI1_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_FBCmFB60, 0, m, &cTabhead_FBCmFB60_sendMessage);
}

void Heavy_ChaffVerb::cVar_2KsF02Dp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2FIEZts5, 0, m, &cVar_2FIEZts5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_48osh9i0, 0, m, &cVar_48osh9i0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_C6Wo7gO9, 0, m, &cVar_C6Wo7gO9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rKb5XsuP, 0, m, &cVar_rKb5XsuP_sendMessage);
}

void Heavy_ChaffVerb::cVar_k39vTacD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.01f, 0, m, &cBinop_oNDn597y_sendMessage);
}

void Heavy_ChaffVerb::cPack_Mb24BZRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sLine_onMessage(_c, &Context(_c)->sLine_ivft9eEj, 0, m, NULL);
}

void Heavy_ChaffVerb::cVar_48osh9i0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gsUblF5C, HV_BINOP_MULTIPLY, 0, m, &cBinop_gsUblF5C_sendMessage);
}

void Heavy_ChaffVerb::cMsg_gAe6dnJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_QUs4hipB_sendMessage);
}

void Heavy_ChaffVerb::cSystem_QUs4hipB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0fZN16vl_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_gsUblF5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_aBehNtXp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_F6cr4ED5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gsUblF5C, HV_BINOP_MULTIPLY, 1, m, &cBinop_gsUblF5C_sendMessage);
}

void Heavy_ChaffVerb::cMsg_0fZN16vl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_F6cr4ED5_sendMessage);
}

void Heavy_ChaffVerb::cBinop_aBehNtXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_gUJGm7dg_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gUJGm7dg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ive3cAy3_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_CNywrojy, m);
}

void Heavy_ChaffVerb::cBinop_ive3cAy3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_rO40fw0f, m);
}

void Heavy_ChaffVerb::cVar_C6Wo7gO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Sy7SfvzH, HV_BINOP_MULTIPLY, 0, m, &cBinop_Sy7SfvzH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_jU3Kljw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Ae9JIlog_sendMessage);
}

void Heavy_ChaffVerb::cSystem_Ae9JIlog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BUN9jMcA_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_Sy7SfvzH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_80jkNOiO_sendMessage);
}

void Heavy_ChaffVerb::cBinop_TKeyVaqw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Sy7SfvzH, HV_BINOP_MULTIPLY, 1, m, &cBinop_Sy7SfvzH_sendMessage);
}

void Heavy_ChaffVerb::cMsg_BUN9jMcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TKeyVaqw_sendMessage);
}

void Heavy_ChaffVerb::cBinop_80jkNOiO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_DZ9kwMSy_sendMessage);
}

void Heavy_ChaffVerb::cBinop_DZ9kwMSy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_aQjsRobr_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_IY16KPQ7, m);
}

void Heavy_ChaffVerb::cBinop_aQjsRobr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_FWHcOkKR, m);
}

void Heavy_ChaffVerb::cVar_rKb5XsuP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cOBDJjLn, HV_BINOP_MULTIPLY, 0, m, &cBinop_cOBDJjLn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Au55F8qH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gJrN4V8L_sendMessage);
}

void Heavy_ChaffVerb::cSystem_gJrN4V8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NglxyiL2_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_cOBDJjLn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_HiMV5gQl_sendMessage);
}

void Heavy_ChaffVerb::cBinop_rqWce3PV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cOBDJjLn, HV_BINOP_MULTIPLY, 1, m, &cBinop_cOBDJjLn_sendMessage);
}

void Heavy_ChaffVerb::cMsg_NglxyiL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_rqWce3PV_sendMessage);
}

void Heavy_ChaffVerb::cBinop_HiMV5gQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_CgSrjonQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CgSrjonQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_nmp8Y2tz_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_rTrv0Ji8, m);
}

void Heavy_ChaffVerb::cBinop_nmp8Y2tz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_qBbLSUUO, m);
}

void Heavy_ChaffVerb::cBinop_QqMx5MH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_IMfhzYHs, 0, m, &cPack_IMfhzYHs_sendMessage);
}

void Heavy_ChaffVerb::cMsg_k5sMsTmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3000.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_2KsF02Dp, 0, m, &cVar_2KsF02Dp_sendMessage);
}

void Heavy_ChaffVerb::cBinop_oNDn597y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_Mb24BZRo, 0, m, &cPack_Mb24BZRo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_48NfRWTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_ysisArw1, 0, m, &cPack_ysisArw1_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_yhedabSE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_zdHOpDjt_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_zdHOpDjt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W1fNGiKx_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cDelay_0FCbEKII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0FCbEKII, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_0FCbEKII, 0, m, &cDelay_0FCbEKII_sendMessage);
  cSwitchcase_mNc7OmaJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_W1fNGiKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zdHOpDjt_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_0FCbEKII, 0, m, &cDelay_0FCbEKII_sendMessage);
  cSwitchcase_mNc7OmaJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cMsg_XXndXCk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1oNITt1a_sendMessage);
}

void Heavy_ChaffVerb::cSystem_1oNITt1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_pJv9GBgR_sendMessage);
}

void Heavy_ChaffVerb::cVar_RlrjzoPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G2BQxeqd, HV_BINOP_MULTIPLY, 0, m, &cBinop_G2BQxeqd_sendMessage);
}

void Heavy_ChaffVerb::cMsg_zdHOpDjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0FCbEKII, 0, m, &cDelay_0FCbEKII_sendMessage);
}

void Heavy_ChaffVerb::cBinop_OSqxxAiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0FCbEKII, 2, m, &cDelay_0FCbEKII_sendMessage);
}

void Heavy_ChaffVerb::cBinop_pJv9GBgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_G2BQxeqd, HV_BINOP_MULTIPLY, 1, m, &cBinop_G2BQxeqd_sendMessage);
}

void Heavy_ChaffVerb::cBinop_G2BQxeqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_OSqxxAiv_sendMessage);
}

void Heavy_ChaffVerb::cVar_eNNMsWrr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MOD_UNIPOLAR, 628.0f, 0, m, &cBinop_aDygP1yv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 2.0f, 0, m, &cBinop_gbw15IyB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_mh2vjejf_sendMessage);
}

void Heavy_ChaffVerb::cVar_K8GWTKZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_lzVNPVG9_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_1rtvzaaV, 0, m, &cIf_1rtvzaaV_sendMessage);
}

void Heavy_ChaffVerb::cUnop_JKSQOcaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bj1jNnXG, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_bj1jNnXG_sendMessage);
}

void Heavy_ChaffVerb::cUnop_R0iXejxy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bj1jNnXG, HV_BINOP_MOD_UNIPOLAR, 1, m, &cBinop_bj1jNnXG_sendMessage);
}

void Heavy_ChaffVerb::cIf_1rtvzaaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_R0iXejxy_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_JKSQOcaQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_lzVNPVG9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1rtvzaaV, 1, m, &cIf_1rtvzaaV_sendMessage);
}

void Heavy_ChaffVerb::cMsg_btthTLxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5DQJrokY_sendMessage);
}

void Heavy_ChaffVerb::cSystem_5DQJrokY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_SHG5UcaM_sendMessage);
}

void Heavy_ChaffVerb::cDelay_Q0x28SwE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Q0x28SwE, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_565aod2N, 0, m, &cDelay_565aod2N_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q0x28SwE, 0, m, &cDelay_Q0x28SwE_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_t26L9f2C, 1, m, NULL);
}

void Heavy_ChaffVerb::cDelay_565aod2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_565aod2N, m);
  cMsg_9Ic8nEcV_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cSwitchcase_fq48Qo7C_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_Fe2N1ebk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cBinop_khLZ1gxD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jnxdw4F9_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::hTable_LsKykipe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y7BL1zgb_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q0x28SwE, 2, m, &cDelay_Q0x28SwE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LY7Lz6t1_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Jnxdw4F9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_LsKykipe, 0, m, &hTable_LsKykipe_sendMessage);
}

void Heavy_ChaffVerb::cBinop_SHG5UcaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 3000.0f, 0, m, &cBinop_khLZ1gxD_sendMessage);
}

void Heavy_ChaffVerb::cMsg_9Ic8nEcV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_LsKykipe, 0, m, &hTable_LsKykipe_sendMessage);
}

void Heavy_ChaffVerb::cCast_LY7Lz6t1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q0x28SwE, 0, m, &cDelay_Q0x28SwE_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Y7BL1zgb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_565aod2N, 2, m, &cDelay_565aod2N_sendMessage);
}

void Heavy_ChaffVerb::cMsg_Fe2N1ebk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_t26L9f2C, 1, m, NULL);
}

void Heavy_ChaffVerb::cTabhead_2OmiD6Le_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1us3fHGC, HV_BINOP_SUBTRACT, 0, m, &cBinop_1us3fHGC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_LXwM5mQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ddTe376J_sendMessage);
}

void Heavy_ChaffVerb::cSystem_ddTe376J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_QDLXB31W_sendMessage);
}

void Heavy_ChaffVerb::cVar_THWGNupx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2x9ZRQs6_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cDelay_QDyiDah0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_QDyiDah0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PKH42TsK, 0, m, &cDelay_PKH42TsK_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_wW3KMCVs, 0, m, &sTabread_wW3KMCVs_sendMessage);
}

void Heavy_ChaffVerb::cDelay_PKH42TsK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PKH42TsK, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_wW3KMCVs, 0, m, &sTabread_wW3KMCVs_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PKH42TsK, 0, m, &cDelay_PKH42TsK_sendMessage);
}

void Heavy_ChaffVerb::sTabread_wW3KMCVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_LqkvS2rw, HV_BINOP_SUBTRACT, 0, m, &cBinop_LqkvS2rw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_gAr1GLCQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4A9d8Djz, HV_BINOP_MAX, 0, m, &cBinop_4A9d8Djz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_QDLXB31W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gAr1GLCQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_gAr1GLCQ_sendMessage);
}

void Heavy_ChaffVerb::cBinop_1us3fHGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aBlnF8As_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_wW3KMCVs, 0, m, &sTabread_wW3KMCVs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_McjZssj1_sendMessage);
}

void Heavy_ChaffVerb::cSystem_iQGZ8Uye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LqkvS2rw, HV_BINOP_SUBTRACT, 1, m, &cBinop_LqkvS2rw_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PKH42TsK, 2, m, &cDelay_PKH42TsK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_2x9ZRQs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_iQGZ8Uye_sendMessage);
}

void Heavy_ChaffVerb::cMsg_aBlnF8As_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_QDyiDah0, 0, m, &cDelay_QDyiDah0_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PKH42TsK, 0, m, &cDelay_PKH42TsK_sendMessage);
}

void Heavy_ChaffVerb::cMsg_TimPI1G3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_4A9d8Djz, HV_BINOP_MAX, 1, m, &cBinop_4A9d8Djz_sendMessage);
}

void Heavy_ChaffVerb::cBinop_4A9d8Djz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1us3fHGC, HV_BINOP_SUBTRACT, 1, m, &cBinop_1us3fHGC_sendMessage);
}

void Heavy_ChaffVerb::cCast_McjZssj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QDyiDah0, 0, m, &cDelay_QDyiDah0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bGqrCd6D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_QDyiDah0, 2, m, &cDelay_QDyiDah0_sendMessage);
}

void Heavy_ChaffVerb::cBinop_LqkvS2rw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_bGqrCd6D_sendMessage);
}

void Heavy_ChaffVerb::cCast_4HTpfWee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_THWGNupx, 0, m, &cVar_THWGNupx_sendMessage);
  cMsg_LXwM5mQq_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_2OmiD6Le, 0, m, &cTabhead_2OmiD6Le_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_genib9NS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BOG7qWCw_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_BOG7qWCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UuQhD1vs_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_zfMBZTj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vrOWX2JR, HV_BINOP_ADD, 0, m, &cBinop_vrOWX2JR_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_3VJynfpy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EBXHJNgw_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_ChaffVerb::cCast_EBXHJNgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6HEXrp9a_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cVar_8GXBPUWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_788QrljP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u8bTFIuH_sendMessage);
}

void Heavy_ChaffVerb::cVar_va9MzQbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f5SbFhSj, 0, m, &cVar_f5SbFhSj_sendMessage);
}

void Heavy_ChaffVerb::cVar_f5SbFhSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CnRukJ3q, HV_BINOP_ADD, 0, m, &cBinop_CnRukJ3q_sendMessage);
}

void Heavy_ChaffVerb::cVar_KSukTfiC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qKiZN8Ky, HV_BINOP_ADD, 0, m, &cBinop_qKiZN8Ky_sendMessage);
}

void Heavy_ChaffVerb::cVar_bwQTItBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_dJrQvQdV_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_3iprGRq9, 0, m, &cIf_3iprGRq9_sendMessage);
}

void Heavy_ChaffVerb::cUnop_g79aMT23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qKiZN8Ky, HV_BINOP_ADD, 1, m, &cBinop_qKiZN8Ky_sendMessage);
}

void Heavy_ChaffVerb::cUnop_YefWu4gU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qKiZN8Ky, HV_BINOP_ADD, 1, m, &cBinop_qKiZN8Ky_sendMessage);
}

void Heavy_ChaffVerb::cIf_3iprGRq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_YefWu4gU_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_g79aMT23_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_dJrQvQdV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3iprGRq9, 1, m, &cIf_3iprGRq9_sendMessage);
}

void Heavy_ChaffVerb::cVar_U3AlKKG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wQQSqfX8_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_mNyH3nOO, 0, m, &cIf_mNyH3nOO_sendMessage);
}

void Heavy_ChaffVerb::cUnop_hFoKbfml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XLwnfoJo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cUnop_CcHWseRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XLwnfoJo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cIf_mNyH3nOO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_CcHWseRU_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_hFoKbfml_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cBinop_wQQSqfX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mNyH3nOO, 1, m, &cIf_mNyH3nOO_sendMessage);
}

void Heavy_ChaffVerb::cSwitchcase_XLwnfoJo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7CV6lEbb, 0, m, &cSlice_7CV6lEbb_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bCfXIFPf, 0, m, &cSlice_bCfXIFPf_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jpqmNaii_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PNHac9kw_sendMessage);
      break;
    }
  }
}

void Heavy_ChaffVerb::cSlice_7CV6lEbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_Bfw6B9uT, 0, m, &cVar_Bfw6B9uT_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_Bfw6B9uT, 0, m, &cVar_Bfw6B9uT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cSlice_bCfXIFPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_wlC0sROc, HV_BINOP_NEQ, 1, m, &cBinop_wlC0sROc_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_Bfw6B9uT, 1, m, &cVar_Bfw6B9uT_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_wlC0sROc, HV_BINOP_NEQ, 1, m, &cBinop_wlC0sROc_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_Bfw6B9uT, 1, m, &cVar_Bfw6B9uT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cVar_Bfw6B9uT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ssrgjj8z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hUa5yZYc_sendMessage);
}

void Heavy_ChaffVerb::cIf_4NUSv0eF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iq4qr1r2_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8Unyo4u1_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_iq4qr1r2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wlC0sROc, HV_BINOP_NEQ, 1, m, &cBinop_wlC0sROc_sendMessage);
}

void Heavy_ChaffVerb::cCast_8Unyo4u1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Bfw6B9uT, 0, m, &cVar_Bfw6B9uT_sendMessage);
}

void Heavy_ChaffVerb::cBinop_wlC0sROc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4NUSv0eF, 1, m, &cIf_4NUSv0eF_sendMessage);
}

void Heavy_ChaffVerb::cCast_jpqmNaii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wlC0sROc, HV_BINOP_NEQ, 0, m, &cBinop_wlC0sROc_sendMessage);
}

void Heavy_ChaffVerb::cCast_PNHac9kw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4NUSv0eF, 0, m, &cIf_4NUSv0eF_sendMessage);
}

void Heavy_ChaffVerb::cIf_1l1qjTrq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_va9MzQbx, 0, m, &cVar_va9MzQbx_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_hqOg6l6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_1l1qjTrq, 0, m, &cIf_1l1qjTrq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_hYv6pzV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_1l1qjTrq, 0, m, &cIf_1l1qjTrq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_utX0ySsi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cIf_onMessage(_c, &Context(_c)->cIf_1l1qjTrq, 0, m, &cIf_1l1qjTrq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cIf_igFfkiHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_8GXBPUWE, 0, m, &cVar_8GXBPUWE_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_ChaffVerb::cCast_o5l2Or9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KSukTfiC, 0, m, &cVar_KSukTfiC_sendMessage);
}

void Heavy_ChaffVerb::cMsg_drlxqODw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_hqOg6l6l, 1, m, &cIf_hqOg6l6l_sendMessage);
}

void Heavy_ChaffVerb::cMsg_D9hyekGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_utX0ySsi, 1, m, &cIf_utX0ySsi_sendMessage);
}

void Heavy_ChaffVerb::cMsg_JOhzetGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_hqOg6l6l, 1, m, &cIf_hqOg6l6l_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_hYv6pzV2, 1, m, &cIf_hYv6pzV2_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_utX0ySsi, 1, m, &cIf_utX0ySsi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_o4bIfA3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zfMBZTj6, 0, m, &cVar_zfMBZTj6_sendMessage);
}

void Heavy_ChaffVerb::cBinop_WsLJXTAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_o4bIfA3m_sendMessage);
}

void Heavy_ChaffVerb::cMsg_6HEXrp9a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_8GXBPUWE, 0, m, &cVar_8GXBPUWE_sendMessage);
}

void Heavy_ChaffVerb::cBinop_bj1jNnXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NTfEdikI, HV_BINOP_MULTIPLY, 0, m, &cBinop_NTfEdikI_sendMessage);
}

void Heavy_ChaffVerb::cBinop_mh2vjejf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bj1jNnXG, HV_BINOP_MOD_UNIPOLAR, 0, m, &cBinop_bj1jNnXG_sendMessage);
}

void Heavy_ChaffVerb::cMsg_kEA2gxFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_hYv6pzV2, 1, m, &cIf_hYv6pzV2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_qKiZN8Ky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AExjEGgI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oMtVWgsB_sendMessage);
}

void Heavy_ChaffVerb::cBinop_y9yHWULy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cluz104w, 0, m, &cVar_cluz104w_sendMessage);
}

void Heavy_ChaffVerb::cCast_AExjEGgI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y9yHWULy, HV_BINOP_ADD, 1, m, &cBinop_y9yHWULy_sendMessage);
}

void Heavy_ChaffVerb::cCast_oMtVWgsB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_va9MzQbx, 0, m, &cVar_va9MzQbx_sendMessage);
}

void Heavy_ChaffVerb::cCast_hUa5yZYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kwJugb8M_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_Ssrgjj8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JOhzetGD_sendMessage(_c, 0, m);
}

void Heavy_ChaffVerb::cBinop_tzY93vAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZyF3XWg3, 0, m, &cVar_ZyF3XWg3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_NTfEdikI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hYv6pzV2, 0, m, &cIf_hYv6pzV2_sendMessage);
}

void Heavy_ChaffVerb::cBinop_n5UBUUiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_utX0ySsi, 0, m, &cIf_utX0ySsi_sendMessage);
}

void Heavy_ChaffVerb::cBinop_BAj5U73K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Qu6BhrSo_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 3.1415f, 0, m, &cBinop_n5UBUUiL_sendMessage);
}

void Heavy_ChaffVerb::cBinop_aDygP1yv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 314.0f, 0, m, &cBinop_RGLCsVDo_sendMessage);
}

void Heavy_ChaffVerb::cBinop_RGLCsVDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_BAj5U73K_sendMessage);
}

void Heavy_ChaffVerb::cBinop_gbw15IyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_eNNMsWrr, 1, m, &cVar_eNNMsWrr_sendMessage);
}

void Heavy_ChaffVerb::cBinop_UAujDSWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QuhCQpwm, 0, m, &cVar_QuhCQpwm_sendMessage);
}

void Heavy_ChaffVerb::cBinop_ECDOjZOn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RlrjzoPj, 0, m, &cVar_RlrjzoPj_sendMessage);
}

void Heavy_ChaffVerb::cMsg_UuQhD1vs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_va9MzQbx, 0, m, &cVar_va9MzQbx_sendMessage);
}

void Heavy_ChaffVerb::cBinop_vrOWX2JR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T3hVmpSb, HV_BINOP_MULTIPLY, 0, m, &cBinop_T3hVmpSb_sendMessage);
}

void Heavy_ChaffVerb::cBinop_T3hVmpSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_igFfkiHj, 0, m, &cIf_igFfkiHj_sendMessage);
}

void Heavy_ChaffVerb::cBinop_nF6zMUT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y9yHWULy, HV_BINOP_ADD, 0, m, &cBinop_y9yHWULy_sendMessage);
}

void Heavy_ChaffVerb::cCast_u8bTFIuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_va9MzQbx, 0, m, &cVar_va9MzQbx_sendMessage);
}

void Heavy_ChaffVerb::cCast_788QrljP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nF6zMUT3, HV_BINOP_ADD, 1, m, &cBinop_nF6zMUT3_sendMessage);
}

void Heavy_ChaffVerb::cCast_9MnAc84P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1l1qjTrq, 1, m, &cIf_1l1qjTrq_sendMessage);
}

void Heavy_ChaffVerb::cCast_hQQuv3pF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_genib9NS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_hsnWwE3u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zfMBZTj6, 0, m, &cVar_zfMBZTj6_sendMessage);
}

void Heavy_ChaffVerb::cCast_BYIKNKG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T3hVmpSb, HV_BINOP_MULTIPLY, 1, m, &cBinop_T3hVmpSb_sendMessage);
}

void Heavy_ChaffVerb::cCast_2IwOxLo4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3VJynfpy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_ChaffVerb::cCast_UuXSubnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_igFfkiHj, 1, m, &cIf_igFfkiHj_sendMessage);
}

void Heavy_ChaffVerb::cCast_Qh6vFPw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zfMBZTj6, 0, m, &cVar_zfMBZTj6_sendMessage);
}

void Heavy_ChaffVerb::cCast_S7XAatKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vrOWX2JR, HV_BINOP_ADD, 1, m, &cBinop_vrOWX2JR_sendMessage);
}

void Heavy_ChaffVerb::cBinop_olJ9m7DJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nF6zMUT3, HV_BINOP_ADD, 0, m, &cBinop_nF6zMUT3_sendMessage);
}

void Heavy_ChaffVerb::cBinop_CnRukJ3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_olJ9m7DJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_olJ9m7DJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_l1ie7CNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_va9MzQbx, 0, m, &cVar_va9MzQbx_sendMessage);
}

void Heavy_ChaffVerb::cCast_FGk7uWmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_olJ9m7DJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_olJ9m7DJ_sendMessage);
}

void Heavy_ChaffVerb::cCast_6Y8PONyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_va9MzQbx, 0, m, &cVar_va9MzQbx_sendMessage);
}

void Heavy_ChaffVerb::cCast_p4H9a42g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CnRukJ3q, HV_BINOP_ADD, 1, m, &cBinop_CnRukJ3q_sendMessage);
}

void Heavy_ChaffVerb::cMsg_G6NNgzXJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ssrgjj8z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hUa5yZYc_sendMessage);
}

void Heavy_ChaffVerb::cReceive_zVgv6CPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Alf0coaY_sendMessage(_c, 0, m);
  cMsg_CnVCIINV_sendMessage(_c, 0, m);
  cMsg_Leyv0cfT_sendMessage(_c, 0, m);
  cMsg_8ex0AYhD_sendMessage(_c, 0, m);
  cMsg_zQBoeYIJ_sendMessage(_c, 0, m);
  cMsg_uQtxBbMc_sendMessage(_c, 0, m);
  cMsg_xiyIUFDP_sendMessage(_c, 0, m);
  cMsg_Mv4xBO6o_sendMessage(_c, 0, m);
  cMsg_VkivXlYp_sendMessage(_c, 0, m);
  cMsg_jSscqJZr_sendMessage(_c, 0, m);
  cMsg_wyFh5gnp_sendMessage(_c, 0, m);
  cMsg_3Kuvqjub_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_2FIEZts5, 0, m, &cVar_2FIEZts5_sendMessage);
  cMsg_gAe6dnJC_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_48osh9i0, 0, m, &cVar_48osh9i0_sendMessage);
  cMsg_jU3Kljw4_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_C6Wo7gO9, 0, m, &cVar_C6Wo7gO9_sendMessage);
  cMsg_Au55F8qH_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_rKb5XsuP, 0, m, &cVar_rKb5XsuP_sendMessage);
  cMsg_vUvCpcOa_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_hA4fkERM, 0, m, &cVar_hA4fkERM_sendMessage);
  cMsg_FDF7kgcE_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_QuhCQpwm, 0, m, &cVar_QuhCQpwm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Hnu0ImOb, 0, m, &cVar_Hnu0ImOb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZyF3XWg3, 0, m, &cVar_ZyF3XWg3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rZczA09m, 0, m, &cVar_rZczA09m_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_D0IlWBbM, 0, m, &cVar_D0IlWBbM_sendMessage);
  cMsg_XXndXCk9_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_RlrjzoPj, 0, m, &cVar_RlrjzoPj_sendMessage);
  cMsg_btthTLxM_sendMessage(_c, 0, m);
  cSwitchcase_hZZHMQyp_onMessage(_c, NULL, 0, m, NULL);
  cMsg_UuQhD1vs_sendMessage(_c, 0, m);
  cMsg_G6NNgzXJ_sendMessage(_c, 0, m);
  cMsg_6HEXrp9a_sendMessage(_c, 0, m);
  cSwitchcase_yhedabSE_onMessage(_c, NULL, 0, m, NULL);
  cVar_onMessage(_c, &Context(_c)->cVar_1mD8oCk9, 0, m, &cVar_1mD8oCk9_sendMessage);
  cMsg_PabYxCZS_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_d88K8eWF, 0, m, &cVar_d88K8eWF_sendMessage);
  cMsg_jN9gxhTI_sendMessage(_c, 0, m);
  cMsg_7PoeOOYi_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ZfGG7kUd, 0, m, &cVar_ZfGG7kUd_sendMessage);
  cMsg_A7Ttnv2X_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_f5scY1oh, 0, m, &cTabhead_f5scY1oh_sendMessage);
  cMsg_CBqWEhec_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Sw6GbnAT, 0, m, &cVar_Sw6GbnAT_sendMessage);
  cMsg_zjxJnl4v_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_2zXlWrsb, 0, m, &cTabhead_2zXlWrsb_sendMessage);
  cMsg_Ds5ZulnE_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_wnPFyn0B, 0, m, &cVar_wnPFyn0B_sendMessage);
  cMsg_xnYlNBKh_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Rx211Gl0, 0, m, &cTabhead_Rx211Gl0_sendMessage);
  cMsg_Q3uOWQhs_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_JiFE195Y, 0, m, &cVar_JiFE195Y_sendMessage);
  cMsg_w5nA9XG4_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_xMW0s7PV, 0, m, &cTabhead_xMW0s7PV_sendMessage);
  cMsg_e21ESNrm_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_f0Fq9lAy, 0, m, &cVar_f0Fq9lAy_sendMessage);
  cMsg_v1qa1HXn_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_SUKWcMMa, 0, m, &cTabhead_SUKWcMMa_sendMessage);
  cMsg_OUcxLTHF_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_u1eOx5yP, 0, m, &cVar_u1eOx5yP_sendMessage);
  cMsg_rqU2zSqx_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_TDE7z6fi, 0, m, &cTabhead_TDE7z6fi_sendMessage);
  cMsg_iLQpyHzm_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_a0vya4bC, 0, m, &cVar_a0vya4bC_sendMessage);
  cMsg_AMa1zYcx_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_MnyGpRp5, 0, m, &cTabhead_MnyGpRp5_sendMessage);
  cMsg_97bDg6Jg_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_CIS60FzH, 0, m, &cVar_CIS60FzH_sendMessage);
  cMsg_XU3A0b54_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Ni9gslk7, 0, m, &cTabhead_Ni9gslk7_sendMessage);
  cMsg_oddK0mys_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_hrAX5gyS, 0, m, &cVar_hrAX5gyS_sendMessage);
  cMsg_PN2OqB6C_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_6kLrEwM8, 0, m, &cTabhead_6kLrEwM8_sendMessage);
  cMsg_B365BTga_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_0QKLlUiN, 0, m, &cVar_0QKLlUiN_sendMessage);
  cMsg_Q6TQsLI1_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_FBCmFB60, 0, m, &cTabhead_FBCmFB60_sendMessage);
  cMsg_TimPI1G3_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_THWGNupx, 0, m, &cVar_THWGNupx_sendMessage);
  cMsg_LXwM5mQq_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_2OmiD6Le, 0, m, &cTabhead_2OmiD6Le_sendMessage);
}

void Heavy_ChaffVerb::cReceive_uvlfLd9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_UAujDSWU_sendMessage);
}

void Heavy_ChaffVerb::cReceive_pzvHUdR0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_U3AlKKG7, 0, m, &cVar_U3AlKKG7_sendMessage);
}

void Heavy_ChaffVerb::cReceive_mNxTGuNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_K8GWTKZM, 0, m, &cVar_K8GWTKZM_sendMessage);
}

void Heavy_ChaffVerb::cReceive_k4Rs6aUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NTfEdikI, HV_BINOP_MULTIPLY, 1, m, &cBinop_NTfEdikI_sendMessage);
}

void Heavy_ChaffVerb::cReceive_q40WJUvW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p4H9a42g_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6Y8PONyG_sendMessage);
}

void Heavy_ChaffVerb::cReceive_0ltOgt84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FGk7uWmJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l1ie7CNs_sendMessage);
}

void Heavy_ChaffVerb::cReceive_w4g9ny8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KSukTfiC, 0, m, &cVar_KSukTfiC_sendMessage);
}

void Heavy_ChaffVerb::cReceive_PMmqFmxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o5l2Or9K_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bwQTItBM, 0, m, &cVar_bwQTItBM_sendMessage);
}

void Heavy_ChaffVerb::cReceive_0yyTzYtm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 157.0f, 0, m, &cBinop_ECDOjZOn_sendMessage);
}

void Heavy_ChaffVerb::cReceive_JeZIaYS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_S7XAatKi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qh6vFPw0_sendMessage);
}

void Heavy_ChaffVerb::cReceive_e6amkfJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BYIKNKG3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hsnWwE3u_sendMessage);
}

void Heavy_ChaffVerb::cReceive_aHUlOjBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UuXSubnO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2IwOxLo4_sendMessage);
}

void Heavy_ChaffVerb::cReceive_aSHpKxhm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_PJkcdRpd, m);
}

void Heavy_ChaffVerb::cReceive_QarmNs34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_HQxI5Asa, m);
}

void Heavy_ChaffVerb::cReceive_70mwynwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Hnu0ImOb, 0, m, &cVar_Hnu0ImOb_sendMessage);
}

void Heavy_ChaffVerb::cReceive_F2guKTqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 100.0f, 0, m, &cBinop_tzY93vAF_sendMessage);
}

void Heavy_ChaffVerb::cReceive_gTLuhfEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AD9WCCnh, 0, m, &cVar_AD9WCCnh_sendMessage);
}

void Heavy_ChaffVerb::cReceive_cbDZKIdA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_l0pAHdj0, 0, m, &cVar_l0pAHdj0_sendMessage);
}

void Heavy_ChaffVerb::cReceive_IHGoGECn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hA4fkERM, 0, m, &cVar_hA4fkERM_sendMessage);
}

void Heavy_ChaffVerb::cReceive_3PvcGdss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_MaqAsMBv, m);
}

void Heavy_ChaffVerb::cReceive_Xw8BQHwD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_WN7iMX2B, m);
}

void Heavy_ChaffVerb::cReceive_bH3fBTi3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gAr1GLCQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_gAr1GLCQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4HTpfWee_sendMessage);
}

void Heavy_ChaffVerb::cReceive_siBIiLw7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9MnAc84P_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hQQuv3pF_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_ChaffVerb::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_phasor_k_f(&sPhasor_0vxpduqX, VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf4), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf5), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf1), VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_IbQRseQ5, VOf(Bf4));
    __hv_line_f(&sLine_CFB57tOG, VOf(Bf1));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf2));
    __hv_tabhead_f(&sTabhead_I3ZJ8s1i, VOf(Bf3));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_g9hHyq0m, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_5zTihDPy, VOf(Bf2));
    __hv_min_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_zero_f(VOf(Bf3));
    __hv_max_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_floor_f(VIf(Bf3), VOf(Bf6));
    __hv_varread_f(&sVarf_TDHf8Amr, VOf(Bf2));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf2), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_NwbS72F7, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_mMjlcZwU, VIi(Bi0), VOf(Bf2));
    __hv_sub_f(VIf(Bf7), VIf(Bf2), VOf(Bf7));
    __hv_sub_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_add_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf0));
    __hv_sub_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_floor_f(VIf(Bf7), VOf(Bf6));
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_abs_f(VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf6), 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f, 0.25f);
    __hv_sub_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf7), 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f, 6.28319f);
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf7), VIf(Bf7), VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf8), 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f, 0.00784314f);
    __hv_var_k_f(VOf(Bf9), 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f, 0.166667f);
    __hv_mul_f(VIf(Bf3), VIf(Bf9), VOf(Bf9));
    __hv_sub_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf6), VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf0), VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_tabhead_f(&sTabhead_XowQl7sS, VOf(Bf4));
    __hv_var_k_f_r(VOf(Bf0), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_GKDcIbr0, VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_wnp1tdI3, VOf(Bf1));
    __hv_min_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_max_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf0));
    __hv_varread_f(&sVarf_vQAxcnNF, VOf(Bf1));
    __hv_zero_f(VOf(Bf8));
    __hv_lt_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_and_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf0), VIf(Bf8), VOf(Bf8));
    __hv_cast_fi(VIf(Bf8), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_jsbnNMEK, VIi(Bi1), VOf(Bf8));
    __hv_tabread_if(&sTabread_njaEGgOw, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf8), VIf(Bf1), VOf(Bf8));
    __hv_sub_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf8), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_kovSpz9r, VIf(I0));
    __hv_varread_f(&sVarf_UYJxN8m4, VOf(Bf2));
    __hv_rpole_f(&sRPole_6uErdXIM, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_Y0yL3Cl1, VIf(Bf2), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_70I1lGSq, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_MaqAsMBv, VOf(Bf1));
    __hv_tabread_f(&sTabread_wW3KMCVs, VOf(Bf5));
    __hv_varread_f(&sVarf_WN7iMX2B, VOf(Bf9));
    __hv_mul_f(VIf(Bf5), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_tabwrite_f(&sTabwrite_t26L9f2C, VIf(Bf9));
    __hv_varread_f(&sVarf_HQxI5Asa, VOf(Bf9));
    __hv_fma_f(VIf(I0), VIf(Bf9), VIf(Bf5), VOf(Bf5));
    __hv_tabread_f(&sTabread_lbMhGGh8, VOf(Bf9));
    __hv_varread_f(&sVarf_0uaubYgj, VOf(Bf1));
    __hv_mul_f(VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_7qWi6hNp, VOf(Bf2));
    __hv_rpole_f(&sRPole_pdfEyZZf, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf2), VIf(Bf9), VOf(Bf2));
    __hv_line_f(&sLine_ivft9eEj, VOf(Bf1));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_X5KtKCoM, VOf(Bf2));
    __hv_tabread_f(&sTabread_G1SDi5ZH, VOf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(Bf0), VOf(Bf8));
    __hv_tabread_f(&sTabread_D6Yszqpj, VOf(Bf4));
    __hv_add_f(VIf(Bf8), VIf(Bf4), VOf(Bf6));
    __hv_tabread_f(&sTabread_AKzQNmPk, VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf3));
    __hv_tabread_f(&sTabread_lRbL4hdp, VOf(Bf10));
    __hv_add_f(VIf(Bf3), VIf(Bf10), VOf(Bf11));
    __hv_tabread_f(&sTabread_2MvsNWAi, VOf(Bf12));
    __hv_add_f(VIf(Bf11), VIf(Bf12), VOf(Bf13));
    __hv_tabread_f(&sTabread_dU5YsroQ, VOf(Bf14));
    __hv_tabwrite_f(&sTabwrite_42ludZgk, VIf(Bf5));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_PQoVLLNo, VIf(Bf0));
    __hv_sub_f(VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_tabwrite_f(&sTabwrite_lu6EhYt8, VIf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_tabwrite_f(&sTabwrite_ELDdyV01, VIf(Bf7));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_03GQTMG4, VIf(Bf12));
    __hv_sub_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_orbJMBl7, VIf(Bf10));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_tabread_f(&sTabread_rgWwA9DW, VOf(Bf9));
    __hv_varread_f(&sVarf_CNywrojy, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_rO40fw0f, VOf(Bf3));
    __hv_rpole_f(&sRPole_ahftubtk, VIf(Bf10), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf3), VIf(Bf9), VOf(Bf3));
    __hv_fma_f(VIf(Bf3), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf13), VIf(Bf14), VOf(Bf9));
    __hv_tabread_f(&sTabread_3Ak4ouDU, VOf(Bf3));
    __hv_varread_f(&sVarf_IY16KPQ7, VOf(Bf10));
    __hv_mul_f(VIf(Bf3), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_FWHcOkKR, VOf(Bf12));
    __hv_rpole_f(&sRPole_U2jGAiAx, VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_sub_f(VIf(Bf12), VIf(Bf3), VOf(Bf12));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf3));
    __hv_tabread_f(&sTabread_1pZDNPqC, VOf(Bf12));
    __hv_varread_f(&sVarf_rTrv0Ji8, VOf(Bf10));
    __hv_mul_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_qBbLSUUO, VOf(Bf11));
    __hv_rpole_f(&sRPole_Ia2YN6SI, VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf11), VIf(Bf12), VOf(Bf11));
    __hv_fma_f(VIf(Bf11), VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf3), VIf(Bf2), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf1));
    __hv_tabwrite_f(&sTabwrite_GZPbtpSe, VIf(Bf1));
    __hv_sub_f(VIf(Bf13), VIf(Bf14), VOf(Bf1));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf11));
    __hv_add_f(VIf(Bf1), VIf(Bf11), VOf(Bf10));
    __hv_tabwrite_f(&sTabwrite_oL7HH7At, VIf(Bf10));
    __hv_sub_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_tabwrite_f(&sTabwrite_fmchOf5p, VIf(Bf12));
    __hv_sub_f(VIf(Bf1), VIf(Bf11), VOf(Bf11));
    __hv_tabwrite_f(&sTabwrite_rxM77lpU, VIf(Bf11));
    __hv_line_f(&sLine_C3gtSON1, VOf(Bf11));
    __hv_mul_f(VIf(Bf13), VIf(Bf11), VOf(Bf13));
    __hv_mul_f(VIf(Bf14), VIf(Bf11), VOf(Bf14));
    __hv_mul_f(VIf(Bf3), VIf(Bf11), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_PJkcdRpd, VOf(Bf2));
    __hv_mul_f(VIf(I0), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf13), VIf(Bf2), VOf(Bf13));
    __hv_add_f(VIf(Bf13), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf14), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf11), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_ChaffVerb::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s)
  float **const bIn = &inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_ChaffVerb::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 1 channel(s), uninterleave
  float *const bIn = inputBuffers;

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
